!
! File is BuildNotes.f90
!
!
! Created on 22 December 2009
!
! This file serves as a repository for Build/ Version comments
!
! David Arthur Sampson
!
! Last Access was: embedded
!                  
! ======================================================================================================
!
! Version 3.03 was the FORTRAN equivalent of the PowerSim Model
!
! Version 3.04:
!        1) Inclusion of the CitiWaterBudgets file.
!
!        2) Rainwater read input (bin\debug\data\prainfall.txt) - currently a place holder until I receive
!             the provider-level rainfall estimates for the valley (from Katharine Hayhoe- Texas Tech).
!
!        3) A correction on the Mead elevation corresponding to Mid-Elevation release Tier. I spoke with 
!             Dr. Fulp (USBR).  Volume on mead is 5.8 maf for elevation of 1025 feet to be used in the 
!             shortage sharing code, or i.e., subroutine threshold_b
!             T,lv_BaEqualization,lvd_Pp,lv_balanceamount,vSsr,vTier)
!
! Version 4.05: 
!        1) Changed the shortage sharing on the Colorado River to reflect actual shortage agreements
!             (i.e., see line 885 in WaterShed_B.f90)
!
!        2) Changed the CAP deliveries to represent all CAP delivered along the aqueduct and NOT the
!             75% of CAP as previously modeled.
!
!        3) Changed the estimate of "on-river".  Tim's original code was not correct. On-river is now 
!             "lv_onRiver=min(wsb%lv_AZshareCO,cv_onRiver-(0.1*wsb%lv_AZshortageCO))" while Pre-cap
!             (before evaporation, is "vPreCap=max(wsb%lv_AZshareCO-lv_onRiver,0)".  NOTE: CAP takes 90% 
!             of the shortage (I ascertained this at an AHS meeting in June, from a CAP contact [Dee Fuerst].
!
!        4) I went back to the original Kent Decree, Table 10, (please see the manuscript draft for the
!             reference)to extract the number of miners inches per acre that each provider gets.  Converting
!             this to Acre Feet provided new (correct?) estimates of class A designations based 
!             on river flow.
!
!        5) I changed the acreage used to calculate class B and C in the model. Heretofore we were using 
!             total acreage (for member lands).  We now use only B and C acreage.  I contacted Tim, and 
!             he is in agreement with this.  I had a meeting with Yvonne Reinink and Tim Skarupa 
!             (19 May 2010) who confirmed this.
!
!        6) Changed SRP release to represent estimates of release based on Class A designations for the 
!             flow of that year.
!
!        7) Added the NCS (new conservation space) allocations to the WaterShed_A.f90 file.  i.e., this 
!             represents water above the "old" dam height up to the new dam height.  This variable is called 
!             "wsa%gv_allocateNCS(i)" or "go_NCS_acft(i)"
!
!        8) Added pumping restrictions so that SRP cannot pump more than the maximum of 375000 acft.  The 
!             variable is called "cv_maxPumping". Pumping is "vDa%lv_SRPpumping_maf(T%year,k)" sent to 
!             the interface as "go_SRPpumping_acft(i)"
!
!        9) Changed the structure of the model a bit; I separated the Provider.f90 file to pull out
!             water demand and population, and the designations for SRP and for CO.  This was 
!             necessary so that SRP release could be modeled, and to clean up the code.  This
!             resulted in the added files: ProviderPopulationandDemand.f90, Designations.f90,and
!             Designations_B.f90.
!
!        10) Water demand was re-evaluated based on comments by Pat; I used new population growth projections
!             from MAG (2005 to 2030) and the 2006 GPCD estimate (from the xls spread sheet) to estimate
!             water demand. AS OF 06.15.10.
!
!        11) I changed the way available water is distributed on the CO when available water is less than normal
!             allocation such that the next time step results in a dead pool level for Mead.  i.e., before
!             I divided the difference between dead pool and available among NV, MX, and AZ.  The code now uses
!             the standard formulation (as when available water exceeds normal allocation) see line 994 in 
!             WaterShed_B.f90 for more specifics.
!
!        12) As of 06.16.10 we have new (up-dated) estimates of groundwater designations (DAWS) and of 
!             certificates for most of our modeled water providers.  We are still working on the few remaining.
!
! Version 4.06: 
!        1) TDS model has been included (continued testing to occur-06.25.10)
!
!        2) Increased storage
!             a) Bartlett Reservoir was increased from 178,186 to to 178,490 (Bureau of Rec data;
!               http://www.usbr.gov/projects/Facility.jsp?fac_Name=Bartlett+Dam
!
!             b) Horseshoe was raised from 109,271 to 131,500 (same reference, except for Horseshoe)
!
!             c) Roosevelt: was 1,653,043 ac-ft, raised to 1,654,080 following the inclusion of NCS (272,500)
!
! Version 4.07
!        1) Remove the use of gm_GlobalOpenFiles; files are now opened in the lm_Initialize module.  This was
!             necessary so that we could use the genericPath String to set the operating path
!
!        2) Added the BuildVerK function to create a combined BuildNum Ver variable that mimics a float; i.e.
!             so I can pass 4.07 to the interface
!
!        3) Changed vList(j) in Designations_SVT to an interger, and changed zero to -1.  Removed 
!             ThresholdDifference(j)
!   
!        4) Changed the  "if(li_thresholddesigSVT(j) < flow)then" to  "if(li_thresholddesigSVT(j-1) < flow)then" 
!             line 186-Designations_SVT.f90 (correction to the code)
!               
!        5) Added acreage for class B&C to include class A,B, and C as directed by David C Roberts (SRP) in 
!             August 2010 meeting (THIS SEEMS TO BE in conflict with other SRP employees) CHECK THIS AGAIN!
!
!        6) Added NCS interface variables to the model. They are:  "go_NCS_acft(j)" and "go_NCSmax_acft(j)".
!             NCS was then added to lv_Designations in Provider.f90.  So, the difference between supply and 
!             demand includes NCS water. 
!
!        7) The variable "go_SRPpumping_acft(i)" was removed.  Using, instead, "go_classBCdesignations(j)" and
!             "go_classBCmax(j)", both in acft yr-1.
!
! Version 4.08
!      11.03.10
!        1) I added an approach to model a reduction in GPCD using a simple exponential smoothing (SES) algorithm
!             found in subroutines.f90.  The variable - gvf_ReductionGPCD_pct=50 - is currently a "fixed" value and must
!             be added to the interface.
!
!        2) I added population estimates for the year 2000 to 2100 (MAG 2007 estimates, reduced by 5% for 2010)
!
!        3) The year 2000 estimates came from www.azcommerce.com/doclib/commune/city.pdf i.e. peoria.pdf
! 
!        4) Together, #22 and #23 give an estimate of water demand, found in Provider.f90 [subroutine  Difference_(T,vGP) ]
!
!        5) I added an approach to model a reduction in outdoor water use (proportion) using the SES algorithm
!             (Brown's).  subroutine is sSES in Water_CityModel.f90
!
! Version 4.09
!      11.16.10
!        1) Added a 25-year trace for climate data and a variable trace.  This is currently hardwired as "lvl_trace25".  When
!             true, 25-years of the historical record are used,  When false, a variable record is used, depending on the index year
!
!        2) I changed the Powell-Mead equalizations as per another look at the Record of Decision dated December 2007.  Specifically,
!             I added the tabular data for 2008 through 2026 as found in the table on page 51.  And, I re-wrote the if blocks for the
!             Tier determinations.  I have kept the original code so that older simulations using the previous balancing method can
!             be examined.  The logical variable is labeled "lvl_RecordOfDecision".  When "true" the modified (new) approach is used.
!             When "false" the code prior to this implimentation is used.  This includes a different approach to estimating the balance
!             amount.  It is my opinion that it (the previous approach) was wrong.
!
!      11.17.10
!        3) Changed the precipitation read input file (Water_CityModel.f90) to include a logical varible (lvl_NCEPmetData) that, when true,
!             reads the formatted meteorological data inputs from the four models/ two emission scenarios used in the NCEP
!             project (one at a time- files need to be copied over into the generic file name 'App_Data\Data\Metdata.txt.'
!
!      12.07.10
!        4) I added a variable to alter the way the min(max()) function for Tier 1 and Tier 3 were operating on balancing Powell and 
!             Mead. I added in 1/2 the flow for the next year to predicted Powell
!             From: 1)  lv_balanceamount=max(0.,(abs((lvd_Pp-lvd_Pm))/2.)  
!             To:   2)  lv_balanceamount=max(0.,(abs((lvd_Pp+ (lv_flow_B_maf(T%year+1)/2.))-lvd_Pm))/2.) 
!             This insures that a max of 9.0 maf is achieved when mead drops below 11.8 maf if the balance amount exceeds 9.0 maf
!             This creates a more realistic release when Mead Drops
!
!      01.03.11
!        5) I added subroutine setReductionGPCDPct(value) and subroutine getReductionGPCDPct(value) (in KernelInterface.f90) 
!             in order to control, from the
!             interface, the reduction in GPCD expected by the year 2100 (using SES algorithm of Browns') see above.
!
! Version 4.1
!      06.27.11
!        1) New KernalInterface parameters (and outputs) for the CityModel parameters - FOR the API release scheduled for 1 July, 2011
!
! Version 5.0 
!      07.12.11
!        1) This Version is now a water demand model.  Outlined in Kernal.for, the order of water source use can be changed.
!        2) The model has water sources from Reclaimed water, RO reclaimed water, and water banking.
!        3) The City-model was restructured, somewhat.  Examine the figure for details
!        4) I am now running the model annually, not monthly.
!        5) The user can now pick from one of three river flow files
!        6) I have added a 4th ProviderDemandOption- SES but you can also change indivdual GPCD's for each provider
!
!      07.28.11
!        7) Fixed the estimate of gwater used (gvf_usedGW(i)) when the aquifer level falls below the designation
!             see line 419 in Groundwater.f90
!
!        8) adjusted lvf_otherWater(i) (see line 438 in Provider.f90) to "fix" GPCD calculations [i.e. DO NOT account for direct Injection
!             and surface water to vadose in the GPCD calculations
!
!        9) I BELIEVE the class A designations have been underestimated.  I went back to the original SAS code and saw that the total
!             providers acreage did not add up to the totals for the Valley for the division of Miner's Inches.  The acreage was off
!             by 27.1%.  See "ReadRawTrottAcres_calculateRights.sas" file
!             and see line 71 in Designations_SVT.f90 - NOTE: the adjustment factor was modified to correct rounding errors, 
!             creating 820,345 AF year-1 at threshold flow (> 1.063507 maf year-1)
!             NOTE: I will adjust the raw input files as soon as I verify and validate this ...
!
!        10) I HAD to change how I was partitioning class A water among on and off-project
!             see line 366 in SRPrelease.f90
!
!        11) I added a Class A water not used- see line 356 in SRPrelease.f90 and line 441 in Provider.f90
!        12) I had missed the Reclaimed water to Vadose flux in the calculation of fluxes to the Vadose
!             - added see line 1309 in Water_CityModel.f90
!
!        13) On 02 August I went back to the Kent Decree to look at the tables for class A lands.  I determined that the total
!             acrege in the file was off by 2333 which was indian lands.  I subtracted that from the total to derive a ratio 
!             to correct, (as I must see it- I cannot replicate the individual water provider acreage based on the decree), the
!             acrege.  See the SAS file listed above. ~ 26 % off
!
!      08.11.11-test Version 08.11.14.00
!        14) I added logical checks to the remaining file open statements (so that all data files have a logical check of presence)
!        15) I made a default value for the ReduceGPCDpct; set at 1% test Version is 08.11.15.30
!
!      08.26.11
!        15) Added code to estimate storage release from the SVT reservoirs -still testing
!
! Version 5.1: 12.20.11
!        1) Added On and off project demand for output to the interface ( go_OnProjectDemand(j) +  go_OffProjectDemand(j) ) 
!        2) Changed the calculation of differencepop(T%year,i) for the start year 
!        3) Added an input from the interface for provider population. Still working out the specifics of
!             this implementation (gii_ProviderPopulation(i)) : assigned to a local variable labeled
!             lvf_ProviderPopFromInterface(T%year,i)
!
!        4) Added CAP water aquired from alternate sources.  This is then CAP water above and beyond the M&I contracts. 
!             This water comes from Tier III and Tier IV CAP water, if available.  I also removed the heretofore "over-estimate"
!             of CAP II water (i.e., 18,145 that was estimated for Tier I and II above and beyond the subcontracts for
!             the 33 water providers.  
!
! Version 5.2: 
!      12.29.11
!        1) Changed the array li_thresholddesigSVT(42) to li_thresholddesigSVT(42,2); has threshold flows but also ratio of flow used
!             by the 10 water providers (i.e., the proportion of total flow used by the sum of all water providers (from table 10; Kent Decree
!             in combination with data that Mike must have provided [provider level acreage])
!
!        2) Changed the input files for the SRP designations of class A based on a re-analysis of the Kent Decree.  Still need to account
!             for acreage differences between the sum of the 10 and that shown in Table 10 of the decree.  As is, I am underestimating
!             release- need to account for the remaining acres..... using mikes data for individual providers, and Table 10 from the Kent
!             decree, the 10 do not add up to the total acreage in the table. Also, Ray still thinks normal flow is incorrect but my reading 
!             of the decree refutes his assumptions UNLESS class A includes, somehow, 3 AF per acre for storage water.... I do not see how,
!             but that is the only way it could be off (in my assessment).  The decree, however, does not state that.. The only way this could be
!             is as if today's use of the term Class A rights for total water (normal flow and storage) is somehow incorporated within the class 
!             A of the decree... UNLESS we can only use class A for on-project.....[this code is no longer considered adequate-01.20.12 (now obsolete]
!                   
!        3) I added the code " if(gvi_kernel_case < 1)gvi_kernel_case=1" to the RunOneYearKernel() subroutine.  This parameter is in the include file.
!             it lets the user change the order of water use.  To this end I also, then, added a set statement in KernelInterface.f90 to affect 
!             this parameter.( subroutine setKernelCase(value)).  At present, a value of 2 places CAP water ahead of class ABC from storage (1 is default)
!
!      01.03.12
!        4) Added lv_State_A_maf() for the year 2000 in initialState_a(). 
!        5) CHANGED (li_acreageSVT(k,1)+li_acreageSVT(k,2)) TO (gvd_acreageSVT(k,1)+gvd_acreageSVT(k,2)) IN 
!             subroutine aDesignations_classBC_A(T,acfta,ltDa,Aout) (~line 381) in Designations_SVT.f90 (li_acreageSVT is the input variable-Unit 42)
!
!        6) Removed class A acres [gvd_acreageSVT(k,1)] from the equation (in the line above).  Cannot add both because some of B&C is classified as A, 
!             but we don't know how much. In addition, have more that ~ 116 k acres which equates to ~ 350 k pumping maximum pumping.
!
!        7) Changed (~line 465 in Designations_SVT.f90) lvf_proportion(j)=Aout%gvf_classBCmax(j)/lvf_sumMax TO lvf_proportion(j)=lvf_acreageProportion(j)in 
!             subroutine aDesignations_classBC_Storage(T,Aout) where:
!              lvf_sumAcreage=0
!               do j = 1,10,1
!               lvf_sumAcreage=lvf_sumAcreage+gvd_acreageSVT(j,2)
!                end do
!                do j = 1,10,1
!               lvf_acreageProportion(j)=gvd_acreageSVT(j,2)/lvf_sumAcreage
!               end do
!               i.e., proportional pumping based on a providers acreage relative to total acres
!
!      01.09.12
!        8) Added indian water type varables for use later (in subroutine aPartition_B)
!             (vDb%lvf_indianII(T%year)= lv_CAPindianTiers_acft(2,1)+lv_CAPindianTiers_acft(2,2)
!             (vDb%lvf_indianIII(T%year)= lv_CAPindianTiers_acft(3,1)+lv_CAPindianTiers_acft(3,2)
! Version 5.3
!        1) added  open(19,FILE=trim(trim(lvc_dataPath)//'App_Data\Data\SVT_doy.txt'),status="old")
!        2) added the fortran file DailyDesignations.f90 to conduct daily SVT provider designations
! 
!      01.18.12
!        3) added a function and variable "fModifyNormalFlow(gvf_modifyNormalFlow)" to modify the 
!             SVT normal flow designations from the trott table (as it is read into an array)
!             to adjust the actual deliveries acre-feet per acre (user reduction from the 1910 statute)
!             gvf_modifyNormalFlow = 1 as default
!             found in the subroutine modifyDesignations()(located in Parameter_control.f90)
!
!        4) added "subroutine setModifyNormalFlow(value)" in the KernelInterface to
!             import the value from the C# interface (read as an integer, divided by 100- proportional basis) 
!
!        5) added the equation to handle changes in modifyNormalFlow to the Parameter_control.f90 file
!
!      01.27.12
!        6) added a function to adjust daily flows on the SVT for the Trott table daily flow designation
!             estimate:  function fmodFlowSVTdaily() found in DailyDesignations.f90
!
!        7) I had to add if statements to modify the drought only when the drought period extends. This
!             was done in the function used (i.e., fmodFlowSVTdaily(T) )
!      02.01.12
!        8) I added a line in Groundwater.f90, line 444; if they have no designation, and the aquifer is
!             >= to their demand, they pump their demand (three water providers have no designation)
!
!        9) as of today, a groundwater designation is their sum total in their aquifer.
!
!        10) Also as of today, I changed (up-dated) populatios with Ray's and Sally's help
!
!      02.02.12
!        11) addded a variable to the kernel interface-gvi_ProviderGroundWater_a(i)- that accepts estimates of
!             initial groundwater, by provider, from the interface. Read in WaterShed.f90, set in Water_CityModel.f90
!             in the aquifer subroutine. This is MODFLOW groundwater passed into the model.
! Version 5.4
!      02.06.12
!        1) Removed the variable providerArea_2006 and used that slot to input providerAcres_2012 which 
!             contains "on" and "off" project acres calculated by Ray on 02.03.12 and housed in the file
!             Provider SRP and OFFProject Acres 2 3 2012.xlsx (ProviderPopulationandDemand.f90)
!             Note: from the original data, Anthem was places as Other Provider and Apache Junction was deleted
!
!        2) altered the  calculation of gvd_classABCacreRatio (ProviderPopulationandDemand.f90) to account
!             for "on" and "off" project using the new data (i.e., "on" acres/ "total" acres). 
!
!        3) Changed the subroutine "ProviderArea2006" to "ProviderArea2012" and changed the formally embedded
!             values to an estimate based on acerage (ProviderPopulationandDemand.f90).
!
!      02.07.12
!        4) Deleted the subroutine   "aDesignations_classA_A(T,flow,gvd_ClassAarray)"
!
!        5) Deleted the subroutine "sSRP_classBandC"
!
!        6) Combined the sSRP_classB&Cstorage subroutine to represent water released from the reservoir plus water
!           pumped by SRP
!
!        7) Changed water use for class A from total demand to "on project" - NOW Ray states on project use only for A & B lands
!           ( subroutine classA(T,gvi_order,Aout) in SRPrelease.f90)
!
!        8) for NCS, changed  lvf_WaterDemand35(i)=gvf_WaterDemand_AF(i,gvi_order,3)*gpd_acftTomaf TO
!            gvf_WaterDemand_AF(i,gvi_order,1)*gpd_acftTomaf 

!      02.08.12
!        9) Changed classB&C a)  Aout%gvf_classBCfromReservoir(i)subtracts calculates the actual release based on demand

!      02.09.12, 02.10.12
!       10) Cleaned up all the files to make them consistent in their look.  Did a bunch of variable checking- outputs
!           making it to the C# interface.
!
!       11) Cleaned up the Include block
!   
!      02.17.12
! Version 5.5
!        1) Changed over to the new population estimates.  Now using providerPopulation_2100.txt
!           Please see TimeSeriesForecastPopulation_17Jan2012.sas and JoinProviderPopulations_2012.sas
!           for complete information. 

!      02.20.12
!        2) Changed the runoff calculations so that we always use the 2000 through 2010 estimates of runoff
!           in the simulation.  Any "added" runoff is concatenated to the file. 
!
!      02.22.12
!        3) Added a correction factor to the SES for GPCD reduction - so, reduction is % reduction by 2085 over
!           2010 estimates (gvf_ReductionGPCD_pct)
!      03.01.12
!        4) Fixed the correction factor (was not working properly) see alpha_SES.sas and
!           GlobalSubroutines.f90 and subroutine SESgpcdRunning()
!         
!      03.05.12
!        5) Added a method of taking Ag water from pumping to add to a water providers
!           groundwater source.  Set in the Interface as subroutine setWaterFromAgPumping(count, values)
!           and subroutine getWaterFromAgPumping(count, values);  Variable name is gvi_WaterFromAgPumping_AF_a(i)
!
!        6) Added the designations for groundwater back into the model.
!
!        7) Added a unit to read data (unit 36) found in Designations_CO.f90.  This file reads the surface water
!           "alloted" to the water providers via the AWS documents (Table ).  We are using these data to calculate
!           the 80% threshold cut-off when providers may pump unlimited groundwater. May no tbe used.....
!
!       03.14.12
!        8) "fixed" normal flow outputs, and verified.
! 
!        9) Added Interface variables for water from the environmnet from colorado river water and from salt and from
!        verde. These have yet to be assigned in the model proper.
!
!       03.21.12
!       10) Major changes to SRP release- normal flow is not captured by the reservoir- passes through.  New code, and
!           new estimates of Spillage (spill over the dam).
!
!       11) Addded an output variable for the Interface - go_spillageSVT - as function getSVTspillage() 
!
!       03.30.12
!       12) Drastically changed my estimate of release from Powell. See line 844 in WaterShed_CO.f90
!
!       04.02.12
!       13) Added powell and mead elevation algorithms...functions in interface- getMeadElevation() and getPowellElevation()
!           from storage--- SAS analysis embedded in the subroutine (fit statistics)            
!            call  elevationsPowell(vState_Ba_maf(T%year),lvf_powellElevation)
!            call  elevationsMead(vState_Bb_maf(T%year),lvf_meadElevation)
!
!       04.05.12
!       14) Changed go_deliveriesCO to be CAP MandI-  I and II sent to the interface

!       04.09.12
!       15) I added on-project proportion of population (2000 to 2030) based on data from Sally;
!         data are read into unit 53 (onProject_2030.txt), with the global variable "gvd_onProjectPop(T%year,lvi_countSRP)" used
!         to pass the info to subroutine calcDemand(T) in ProviderPopulationandDemand.f90.
!      
!       04.16.12
!       16) Fixed the drought factor parameter for the SVT daily flow records.  Heretofore the drought response kicked in
!           immediately and did not turn off.
!      
! -----------------------------------------------------------------------------------------------------------------------------------------
!    
Module lm_BuildNotes
  use gm_VersionControl
  !
 contains
  !
  function BuildNumK() result(num)
    num = 5
  end function
  function BuildVerK() result(num)
    num = 5
  end function
  function MonthK() result(num)
    num=gdi_Month !dt(2)
  end function
  function DayK() result(num)
    num=gdi_Day
  end function
  function HourK() result(num)
    num=gdi_Hour
  end function
  function MinK() result(num)
    num=gdi_Min
  end function 
  !
End Module lm_BuildNotes
! ----------------------
! E.O.F