!
! File is Energy_CAP.f90
!
!  This file contains the code for modeling the energy required in pumping CAP water along the 
! aqueduct to Granite Reef.
!
! OUTPUTS:
!
! created on 10.08.09
!
! david arthur sampson
! last write was: 02.10.12
! ------------------------
!
! =================================================================================================
!
Module mEnergyCAP
 use gm_ModelControl
   use gm_GlobalData
    use gm_TypeControl
     use gm_Euler

    implicit none
   ! --------------
    !
    include 'C:\WaterSim\WaterSimTesting\WaterSimTesting\bin\Debug\App_Data\WaterSim_4_0\App_Data\Include\WaterSimDCDC.txt'
    !
    type CAPenergy
     real(8) :: lv_reachkWhra(7),lv_TWhr(7),lv_holdD1,lv_holdD2
     real :: lv_storage(7),lv_holdF1
    end type CAPenergy
! =================================================================================================
  contains
    subroutine aquaduct(T,vCAPHavasu_dt,oCE)

        integer :: i,j,k
        real(8) :: fAcftperannumTocfts  ! function
        !
        ! vMarkWilmer,vBouseHills,vLilHarquahala,vHassayampa, vWadell
        ! -------------------------------------------------------------
        real(8) :: vHht(7)          ! Mark Wilmer 
                                    ! Bouse Hills
                                    ! Little Harquahala
                                    ! Hassaympa
                                    ! Wadell
        !
        !  173.9 miles total from LH to Granite Reef
        !  (need to Wadell)
        ! ------------------------------------------
        real(8) :: vE = 0.8
        real(8) :: hp(7)                  ! Horse power
        real(8) :: lv_kwHr(7)
        !
        real(8) :: vSeepageC = 1. 
        real(8) :: vLoss(7)
        !
        real(8) :: lv_conveyance(7),lv_removals(7)
        !
        real(8) :: fHorsePowerCAP
        real(8) :: fKilowatthrsFromHP
        real(8) :: vCAPHavasu_dt

        type(CAPenergy)oCE
        type(runTime)T
        !=======================
        ! 
        do i = 1,7,1
          lv_removals(i)=0.
          lv_conveyance(i)=0.
          hp(i)=0.
          lv_kwHr(i)=0.
          oCE%lv_TWhr(i)=0.
        end do
        !  Head "lift" for each reach
        vHht(1)=824.    ;vHht(2)=90.    ;vHht(3)=80.    ;vHht(4)=90.    ;vHht(5)=264.
        vHht(6)=0.      ;vHht(7)=0.
        !
        !  Not used yet.  Could be water removed for Tonoapah and agua fria storage, etc
        vLoss(1)=0.     ;vLoss(2)=0.    ;vLoss(3)=0.    ;vLoss(4)=0.    ;vLoss(5)=0.
        vLoss(6)=0.     ;vLoss(7)=0.
        !
        do i = 1,5,1
         lv_removals(i)=fAcftperannumTocfts(T%days,oCE%lv_storage(i)*1/gpd_acftTomaf)
        end do
        !
        lv_conveyance(1)=vCAPHavasu_dt
        do i = 2,4,1
         lv_conveyance(i)=lv_conveyance(i-1)*vSeepageC-vLoss(i)-lv_removals(i)
        end do
        lv_conveyance(5)=200.          ! for now, 200 ft3 s (~ 145k acft a-1) pumped into Wadell
        !
        ! kilowatt hours
        do j = 1,5,1
         hp(j)=fHorsePowerCAP(vHht(j),vE,lv_conveyance(j))
         lv_kwHr(j)=fKilowatthrsFromHP(hp(j))

        end do
        !
        ! Terawatt hours annum-1
        do k=1,5,1
         oCE%lv_TWhr(k)=(lv_kwHr(k)*24*T%days)/1e9
        end do
        !
        !
10      format(F6.1,1x,F7.2,1x,F7.2,1x,F12.2)
        !
     return
    end subroutine aquaduct
    ! ---------------------
  
    ! ---------------------
    subroutine sStorage(oCE)

        type(CAPenergy)oCE
        !
        call storage_1(oCE)
        call storage_2(oCE)
        !
      return
    end subroutine sStorage
    ! ---------------------

        ! -----------------------
        subroutine storage_1(oCE)
            integer :: i
            type(CAPenergy)oCE
            
            do i = 1,7,1
             oCE%lv_storage(i)=0.
            end do
            ! tonopah
            oCE%lv_storage(4) = 0.104088   ! maf a-1
         
        end subroutine storage_1
        ! ----------------------

        ! -----------------------
        subroutine storage_2(oCE)

            type(CAPenergy)oCE

            ! agua fria
             oCE%lv_storage(5) = 0.007078 ! maf a-1

        end subroutine storage_2
        ! ----------------------

    ! ----------------------------------
    subroutine eulerCAPenergy(T,oCE,vEC)

        integer :: i

        real(8):: x0=0.
        real(8):: yf
        real(8):: y
        real(8):: outE(12)            ! monthly data

        type(CAPenergy)oCE
        type(Energy)vEC
        type(runTime)T
        !==============
        !
            y=x0
           yf=sum(oCE%lv_TWhr)
         call sEuler(outE,y,x0,yf,12)
           y=yf
        !  Output is GWh month-1 cumulative for the year
        do i = 1,12,1
         vEC%gv_eCAP_used_GWhMcum(2,i)=outE(i)*1000
         vEC%gv_eCAP_used_GWhMcum(1,i)=y
        end do
        !
      return
    end subroutine eulerCAPenergy
    ! -------------------------

    ! --------------------------
    subroutine outputsCAP(T,oCE)

        type(CAPenergy)oCE
        type(runTime)T
        ! ===============
         !
         ! Output to the interface
         go_energyusedinpumpingCAP=nint(sum(oCE%lv_TWhr)*1000 )
         !
            ! Once through the module- write to the log file
            ! ==============================================
            if(T%year == T%startyear)then
             if(gvl_WriteToDisk)&
             write(7,*)"  Lake Havasu CAP energy:"
            endif
            !
      return
    end subroutine outputsCAP
    ! -----------------------
End module mEnergyCAP
    !
    ! ------------------------------
    subroutine sLakeHavasu(T,Bin,vEC)
      use mEnergyCAP

        real(8) :: CAPw     ! maf a-1
        real(8) :: fAcftperannumTocfts
        real(8) :: vCAPHavasu_dt
        real(8) :: vCAPHavasu

        type(RiverB)Bin
        type(CAPenergy)oCE
        type(Energy)vEC
        type(runTime)T
        !=======================
        ! 24 May, 2010 changed to total CAP water
         CAPw=Bin%bCAP_maf
        call sStorage(oCE)
        vCAPHavasu=CAPw+oCE%lv_storage(4)+oCE%lv_storage(5)
        vCAPHavasu_dt=fAcftperannumTocfts(T%days,vCAPHavasu* (1./gpd_acftTomaf))
        !
        call aquaduct(T,vCAPHavasu_dt,oCE)
        call eulerCAPenergy(T,oCE,vEC)
        call outputsCAP(T,oCE)
        !
     return
    end subroutine sLakeHavasu
    !
! =================================================================================================
! E.O.F.