!
! File is Energy_CityModel.f90
!
! This code models the energy requirements of the City Model - NOT all states are 
! modeled.  Needs updating

! Created on: 02.07.10
!
! last write was: 02.10.12
! -------------------------
!
! =================================================================================================
Module lms_EnergyNCEP
 use gm_ModelControl
  use gm_GlobalData
   use gm_TypeControl
   
    implicit none
     !
    include 'C:\WaterSim\WaterSimTesting\WaterSimTesting\bin\Debug\App_Data\WaterSim_4_0\App_Data\Include\WaterSimDCDC.txt'
    !
     real, parameter :: vkWhrMgalTokWhrAcFt=0.32585143
     real, parameter :: vSWtoWTP(gvi_maxProV)=593
     real, parameter :: vGWtoWTP(gvi_maxProV)=593

     real, parameter :: vLBSperft3=62.4
     real, parameter :: vFtlbspersec=550
     real, parameter :: vSecTomonths=2627999.99
     real, parameter :: vSecToyear=31536000
     real, parameter :: vHpTokW=0.745699872
     real, parameter :: vHrToMonth=729.999998
     real, parameter :: vHrToyear=8760
    !
    type NCEPenergy
      real :: lv_eSWtoWTP(gvi_maxProV,12),lv_eWTPtoWS(gvi_maxProV,12)
      real :: lv_eGWtoWTP(gvi_maxProV,12), lv_eGWtoSURFACE(gvi_maxProV,12)
      real :: lv_eGWorOthertoAg(gvi_maxProV,12)
      real :: lv_eWaterEff(6,gvi_maxProV,12)
      real :: lvf_ePumpingEfficiency(gvi_maxProV)
    end type NCEPenergy
    ! =============================================================================================
  contains
    subroutine sSWtoWTP(i,j,vWBe,vLEB)

      integer i,j
      type(EnergyWB)vWBe
      type(NCEPenergy)vLEB
      ! ==================
        ! Acft month-1 * 593 (kWhr per Mgal) * 0.3258 (Mgal to Acft)
        vLEB%lv_eSWtoWTP(i,j)=vWBe%gv_wSWtoWTP(i,j)*vSWtoWTP(i)*vkWhrMgalTokWhrAcFt
        !
     return
    end subroutine sSWtoWTP
    ! ---------------------

    ! --------------------------------
    subroutine sWTPtoWS(i,j,vWBe,vLEB)

      integer i,j
      real,parameter :: vWTPhead(gvi_maxProV,2)=100 ! 100 feet elevation up to service area
      real :: vHeadLoss(gvi_maxProV,2),vHL(gvi_maxProV),vHm(gvi_maxProV)
      real, parameter :: vDistance(gvi_maxProV,2)=4 ! 4 miles from WTP to society
      real, parameter :: vEfficiency=0.8
      real, parameter :: vFtMile=5280
      real, parameter :: vHrsday=24
      real :: lv_dia
      real :: lv_horsePower(gvi_maxProV,12,2),lv_kWhday(gvi_maxProV)
      real :: lv_pumpingefficiency(gvi_maxProV)

      type(EnergyWB)vWBe
      type(NCEPenergy)vLEB
      ! ==================
        ! verified on 02.19.10 das
        !
        ! Head loss per one mile (5280 feet in one mile, pipe dia is 10ft)
        !
        ! in the HZ function, 
        ! do I need to multiple vFtMile * 4 to be correct here?????
        lv_dia=10
        !
        if(gpi_timeStep /=1)then
          vHL(i)=fHazenWilliams(vWBe%gv_wWTPtoWS(i,j),12,vFtMile,lv_dia)
          vHm(i)=0.25* vHL(i)
          vHeadLoss(i,1)=(vHL(i)+vHm(i))*vDistance(i,1) + vWTPhead(i,1)
          !
           lv_horsePower(i,j,1)=fHorsePowerE_CM(vWBe%gv_wWTPtoWS(i,j),12,vHeadLoss(i,1),vEfficiency)
          vLEB%lv_eWTPtoWS(i,j)=lv_horsePower(i,j,1)*vHpTokW*vHrToMonth
        else
          vHL(i)=fHazenWilliams(vWBe%gv_wWTPtoWS(i,j),1,vFtMile,lv_dia)
          vHm(i)=0.25* vHL(i)
          vHeadLoss(i,1)=(vHL(i)+vHm(i))*vDistance(i,1) + vWTPhead(i,1)
          !
           lv_horsePower(i,j,1)=fHorsePowerE_CM(vWBe%gv_wWTPtoWS(i,j),1,vHeadLoss(i,1),vEfficiency)
          !
          lv_kWhday(i)=lv_horsePower(i,j,1)*vHpTokW*vHrsday
           if(vWBe%gv_wWTPtoWS(i,j)>0.)lv_pumpingefficiency(i)= &
            lv_kWhday(i)/(vWBe%gv_wWTPtoWS(i,j)/365.)  ! kWh per acft
          vLEB%lv_eWTPtoWS(i,j)=lv_horsePower(i,j,1)*vHpTokW*vHrToyear
          vLEB%lvf_ePumpingEfficiency(i)=lv_pumpingefficiency(i)
        endif
        !
      return
    end subroutine sWTPtoWS
    !----------------------

    ! --------------------------------
    subroutine sGWtoWTP(i,j,vWBe,vLEB)

     integer i,j
      real,parameter :: vHead(gvi_maxProV,2)=180
      real,parameter :: vEfficiency=0.9
!      real :: lv_ft3sec   ! 08.18.10
      real :: lv_pumpingefficiency(gvi_maxProV)

      real :: lv_horsePower(gvi_maxProV,12,2)

      type(EnergyWB)vWBe
      type(NCEPenergy)vLEB
      ! ==================
        ! certified on 02.19.10 das 
        if(gpi_timeStep /=1)then
            ! kWhr month-1 Pumping
           lv_horsePower(i,j,1)=fHorsePowerE_CM(vWBe%gv_wGWtoWTP(i,j),12,vHead(i,1),vEfficiency)
         
            vLEB%lv_eGWtoSURFACE(i,j)=lv_horsePower(i,j,1)*vHpTokW*vHrToMonth
            ! Acft month-1 * 593 (kWhr per Mgal) * 0.3258 (Mgal to Acft)
            ! From Pump site to SWTP
          vLEB%lv_eGWtoWTP(i,j)=vLEB%lv_eGWtoSURFACE(i,j)+ &
            (vWBe%gv_wGWtoWTP(i,j)*vGWtoWTP(i)*vkWhrMgalTokWhrAcFt)

        else
!           lv_ft3sec=vWBe%gv_wGWtoWTP(i,j)*gpd_acftToft3*1./vSecToyear
           lv_horsePower(i,j,1)=fHorsePowerE_CM(vWBe%gv_wGWtoWTP(i,j),1,vHead(i,1),vEfficiency)
            if(vWBe%gv_wGWtoWTP(i,j) >0.)lv_pumpingefficiency(i)=&
               (lv_horsePower(i,j,1)*vHpTokW*24.)/(vWBe%gv_wGWtoWTP(i,j)/365.)
          !
          vLEB%lvf_ePumpingEfficiency(i)=lv_pumpingefficiency(i)
          vLEB%lv_eGWtoSURFACE(i,j)=lv_horsePower(i,j,1)*vHpTokW*vHrToyear
          vLEB%lv_eGWtoWTP(i,j)= vLEB%lv_eGWtoSURFACE(i,j)+&
            (vWBe%gv_wGWtoWTP(i,j)*vGWtoWTP(i)*vkWhrMgalTokWhrAcFt)
        endif
       return
    end subroutine sGWtoWTP
    ! ---------------------

    ! -------------------------------
    subroutine sGWtoAgI(i,j,vWBe,vLEB)

      integer i,j
      real,parameter :: vHead(gvi_maxProV,2)=180
      real,parameter :: vEfficiency=0.9

      real :: lv_horsePower(gvi_maxProV,12,2)

      type(EnergyWB)vWBe
      type(NCEPenergy)vLEB
      ! ==================
        !
        if(gpi_timeStep /=1)then
           lv_horsePower(i,j,1)=fHorsePowerE_CM(vWBe%gv_wGWtoAg(i,j),12,vHead(i,1),vEfficiency)
          vLEB%lv_eGWorOthertoAg(i,j)=lv_horsePower(i,j,1)*vHpTokW*vHrToMonth
        else
           lv_horsePower(i,j,1)=fHorsePowerE_CM(vWBe%gv_wGWtoAg(i,j),1,vHead(i,1),vEfficiency)
          vLEB%lv_eGWorOthertoAg(i,j)=lv_horsePower(i,j,1)*vHpTokW*vHrToyear
        endif
        !
      return
    end subroutine sGWtoAgI
    ! ---------------------

    ! -----------------------------------------
    subroutine sOutputsCME(T,i,j,vLEB,vWBe,vEM)
        integer :: i,j
        real(8) :: lv_maricopa

        type(Energy)vEM
        type(EnergyWB)vWBe
        type(runTime)T
        type(NCEPenergy)vLEB
        ! ==================
          !
          if(i == 1)then
            lv_maricopa=0
          endif
          !
          vEM%gv_eCMout(i,j)=vLEB%lv_eSWtoWTP(i,j)+vLEB%lv_eWTPtoWS(i,j)+vLEB%lv_eGWtoWTP(i,j) &
            + vLEB%lv_eGWorOthertoAg(i,j)
          !
!          lv_wTotal_acft(i,j)=(vWBe%gv_wSWtoWTP(i,j)+vWBe%gv_wWTPtoWS(i,j)+vWBe%gv_wGWtoWTP(i,j) &
!            + vWBe%gv_wGWtoAg(i,j))
          !
!          lv_eTotal_MWhr(i,j)=vEM%gv_eCMout(i,j)*0.001 ! kWh to MWh month-1
          lv_maricopa=lv_maricopa+vEM%gv_eCMout(i,j)
         !
         ! NCEP "special projects" send to Water_CityModel.f90 outputs
         ! 11.15.10 das
         ! ------------------------------------------------
         vEM%gv_eSWtoWTP(i,j)=vLEB%lv_eSWtoWTP(i,j)*0.001
         vEM%gv_eWTPtoWS(i,j)=vLEB%lv_eWTPtoWS(i,j)*0.001
         vEM%gv_eGWtoWTP(i,j)=vLEB%lv_eGWtoWTP(i,j)*0.001
         vEM%gv_eGWtoAg(i,j)=vLEB%lv_eGWorOthertoAg(i,j)*0.001

          ! Send CAP energy costs
    
         ! -----------------------------------------------------
          if(vWBe%gv_wSWtoWTP(i,j) >0)vLEB%lv_eWaterEff(1,i,j)=(vLEB%lv_eSWtoWTP(i,j))/vWBe%gv_wSWtoWTP(i,j) ! kWhr per acft
          if(vWBe%gv_wWTPtoWS(i,j) >0)vLEB%lv_eWaterEff(2,i,j)=(vLEB%lv_eWTPtoWS(i,j))/vWBe%gv_wWTPtoWS(i,j)
          if(vWBe%gv_wGWtoWTP(i,j) >0)vLEB%lv_eWaterEff(3,i,j)=(vLEB%lv_eGWtoWTP(i,j))/vWBe%gv_wGWtoWTP(i,j)
          !
            ! NCEP "special projects" outputs energy
            ! 11.15.10 das
            ! ----------------------------------------------
            ! Examine:
            !         1) 

10 format(I4,2x,I2,1x,3(F12.2,1x))
!write(,*)i,j,vLEB%lv_eSWtoWTP(i,j),vLEB%lv_eWTPtoWS(i,j),vLEB%lv_eGWtoWTP(i,j), &
      !     vLEB%lv_eGWtoSURFACE(i,j),vLEB%lv_eGWorOthertoAg(i,j)
!write(,*)i,j,(vLEB%lv_eWaterEff(1,i,j)+vLEB%lv_eWaterEff(2,i,j)+vLEB%lv_eWaterEff(3,i,j)),vEM%gv_eCMout(i,j)*0.001
          !
        return
    end subroutine sOutputsCME
    ! ------------------------

    ! --------------------------------------------------
    function fHorsePowerE_CM(acft,vTimeStep,head,efficiency)

      integer :: vTimeStep
      real :: acft,head,efficiency,conversion
      real :: lv_ft3sec
      real :: fHorsePowerE_CM
      !
         fHorsePowerE_CM=0
         lv_ft3sec=0
         conversion=vSecToyear
        if(vTimeStep == 12)conversion=vSecTomonths
        !
        lv_ft3sec=acft*gpd_acftToft3* (1./conversion)
        fHorsePowerE_CM=(vLBSperft3*lv_ft3sec*head) * (1/ (vFtlbspersec*efficiency))
        !
      return
    end function fHorsePowerE_CM
    ! --------------------------

    ! --------------------------------------------------------
    function fHazenWilliams(acft,vTimeStep,pipelength,pipedia)

      integer :: vTimeStep
      real, parameter :: vFrictionfac=0.035
      real :: acft,pipelength,pipedia,conversion
      real, parameter :: pi=3.1415926
      real :: lv_ft3sec
      real :: Velocity
      real :: fHazenWilliams
      !
        !
         fHazenWilliams=0
         conversion=vSecToyear
         lv_ft3sec=0
         Velocity=0
        !
        if(vTimeStep == 12)conversion=vSecTomonths
        lv_ft3sec=acft*gpd_acftToft3*1./conversion
        !
        Velocity=lv_ft3sec/(pi*((pipedia**2)/4))
        !
        fHazenWilliams=vFrictionfac*(pipelength/pipedia)*(Velocity**2 /(2*32.2))
      !
    end function fHazenWilliams

End Module lms_EnergyNCEP
!
!   Called from Water_CityModel.f90
    ! --------------------------------------------
    subroutine sCityModelEnergy(T,i,j,vWBin,vEMin)
      use lms_EnergyNCEP
       use gm_ModelControl
       
        integer :: i,j

         type(EnergyWB)vWBin
         type(Energy)vEMin
         type(NCEPenergy)lvtLEB
         type(runTime)T
        ! =====================
          !
          call sSWtoWTP(i,j,vWBin,lvtLEB)
          call sWTPtoWS(i,j,vWBin,lvtLEB)
          call sGWtoWTP(i,j,vWBin,lvtLEB)
          call sGWtoAgI(i,j,vWBin,lvtLEB)
          !
          call sOutputsCME(T,i,j,lvtLEB,vWBin,vEMin)
        !
    end subroutine sCityModelEnergy
! ---------------------------------
!
! =================================================================================================
! E.O.F.