!
!  File is KernelInterface.f90
!
!  This is the FORTRAN Interface to the C# interface for the model suite
!
! Created on 06.07.10
!
! Last modified on 02.10.12
! _________________________
!

! =================================================================================================
!
! Run connection and controls
! ---------------------------
!
!
! Data and output paths
! =====================
subroutine SetStringData (selector, newValue)
 use lm_Kernel
    dll_export :: SetStringData
    integer, intent (in) :: selector
    character, dimension(200), intent (in) :: newValue
    ! Convert from array of single characters into single string
    character(len=200) :: str
    write(str,"(200a1)") newValue
    !
    !print *,"",selector,"Data"
    gvc_DPath=str
    !
end subroutine SetStringData
!
subroutine SetStringOutput (selector, newValue)
 use lm_Kernel
    dll_export :: SetStringOutput
    integer, intent (in) :: selector
    character, dimension(200), intent (in) :: newValue
    ! Convert from array of single characters into single string
    character(len=200) :: str
    write(str,"(200a1)") newValue

    !print *,"",selector,"Output"
!    print *,""
   
   ! Do something with string
   gvc_OPath=str
   !
end subroutine SetStringOutput
!
! Build version
! ============================
function BuildNum() result(num)
    use lm_BuildNotes
    implicit none
    integer :: num
    dll_export BuildNum

    num = BuildNumK()
end function
!
function BuildVer() result(num)
    use lm_BuildNotes
    implicit none
    integer :: num
    dll_export BuildVer

    num = BuildVerK()
end function
!
function TestMonth() result(num)
    use lm_BuildNotes
    implicit none
    integer :: num
    dll_export TestMonth
    num = MonthK()
end function
function TestDay() result(num)
    use lm_BuildNotes
    implicit none
    integer :: num
    dll_export TestDay
   
    num = DayK()
end function
function TestHour() result(num)
    use lm_BuildNotes
    implicit none
    integer :: num
    dll_export TestHour
    num = HourK()
end function
function TestMin() result(num)
    use lm_BuildNotes
    implicit none
    integer :: num 
    dll_export TestMin
    
    num = MinK()
end function


! Initialize all variables
! ===============
subroutine Init()
    use lm_Initialize
    implicit none
    dll_export :: Init
    !
    call initK()
 return
end subroutine
!
function getStatus() result(value)
 use gm_GlobalData

    implicit none
    integer :: value
    dll_export :: getStatus

    value = gv_exceptionCode
end function
!
! Run the model one year
! =====================
subroutine RunOneYear()
    use lm_Kernel

    implicit none
    dll_export :: RunOneYear

    call RunOneYearKernel()
   
end subroutine RunOneYear
!
subroutine OpenFiles()
 use lm_Start
   implicit none
    dll_export :: OpenFiles

    call OpenFilesK()

end subroutine OpenFiles
!
subroutine CloseFiles()
 use lm_Terminate
  implicit none
    dll_export :: CloseFiles

    call CloseFilesK()

end subroutine CloseFiles
!
subroutine InitState()
    use lm_Initialize
    implicit none
    dll_export :: InitState
    !
    call InitStates()
    !
 return
end subroutine InitState
! ----------------------------------!
! Test code 
! =========
!  function dllOUT() result(SVT_river)
!    use lms_WaterSimTest1    
!    implicit none
!
!    dll_export :: dllOUT
!    type(SVTonto_r):: SVT_river
!    !
!    SVT_river%gvi_release=100000
!!    call returnType(SVT_river)
!    !
!  end function 
!
!  Initial conditions
!
!-----------------------------------------!
!
!   C# interface = internal int KernelCase
!
subroutine setKernelCase(value)
    use lm_Kernel
    implicit none
    dll_export :: setKernelCase
    integer :: value

   gvi_kernel_case=value
end subroutine
!
function getStartSimulation() result(value)
    use lm_Kernel
    implicit none
    dll_export :: getStartSimulation
    integer :: value

   value=gvi_startSimulationYear
end function
subroutine setStartSimulation(value)
    use lm_Kernel
    implicit none
    dll_export :: setStartSimulation
    integer :: value

   gvi_startSimulationYear=value
end subroutine
!
function getEndSimulation() result(value)
    use lm_Kernel
    implicit none
    dll_export :: getEndSimulation
    integer :: value

   value=gvi_endSimulationYear
end function
subroutine setEndSimulation(value)
    use lm_Kernel
    implicit none
    dll_export :: setEndSimulation
    integer :: value

   gvi_endSimulationYear=value

end subroutine
function getWriteStatus() result(value)
    use lm_Kernel
    implicit none
    dll_export :: getWriteStatus
    logical :: value

   value=gvl_WriteToMyDisk
end function
subroutine setWriteStatus(value)
    use  lm_Initialize
    implicit none
    dll_export :: setWriteStatus
    logical :: value

    gvl_WriteToMyDisk=.false.
   if(value)gvl_WriteToMyDisk=value

end subroutine
subroutine setValidate(value)
    use  lm_Initialize
    implicit none
    dll_export :: setValidate
    logical :: value

    gvl_Validate=.false.
   if(value)gvl_Validate=value

end subroutine






! -------------------------------!
!
! =======================================================================================
!
! Inputs - Regional Scale
!
!----- Salt/Verde River Input Variables -------------------!
!
! Runoff data to use seee line 55 in WaterShed_SVT.f90
! ========
!

! 01.18.12 DAS
subroutine getModifyNormalFlow(count, values)
    use lm_ParameterControl
    implicit none
    dll_export :: getModifyNormalFlow
    integer :: count,i
    integer, dimension(1:count) :: values
    !

    forall(i=1:count) values(i) = gvf_modifyNormalFlow(i) * 10
    !
end subroutine
!
subroutine setModifyNormalFlow(count, values)
    use lm_ParameterControl
    implicit none
    dll_export :: setModifyNormalFlow
    integer :: count,i
    integer :: mydefault=1
    integer, dimension(1:count) :: values
    real, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=mydefault
    forall(i=1:count, values(i) .gt. 0)
      generic(i) = values(i) * 0.1
    end forall
    !
    forall(i=1:count) gvf_modifyNormalFlow(i)= generic(i) 
    !
end subroutine

! C# interface =  public override int SaltVerdeTontoHistoricalData 
!
function getSVTHistData() result(value)
    use lms_River_Aa
    implicit none
    dll_export :: getSVTHistData
    integer :: value

    gv_dataSVT=1
    value=gv_dataSVT

end function
subroutine setSVTHistData(value)
    use lms_River_Aa
    implicit none
    dll_export :: setSVTHistData
    integer :: value
    
    gv_dataSVT=1
    if(1 < value)gv_dataSVT=value
    !
end subroutine
!
! Index year (year to start)
! ========
!
! C# interface =  public override int SaltVerdeHistoricalExtractionStartYear 
!
function getSVHistExtractionStartYear() result(value)
    use lms_River_Aa
    implicit none
    integer :: value
    dll_export :: getSVHistExtractionStartYear

    value = gv_indexyearSVT
end function
subroutine setSVHistExtractionStartYear(value)
    use lms_River_Aa
    implicit none
    dll_export :: setSVHistExtractionStartYear
    integer :: value

    gv_indexyearSVT=value
end subroutine
!
! Climate factor (proportional)
! ========
!
! C# interface =public override int SaltVerdeClimateAdjustmentPercent
!
function getSVClimateAdjustmentPercent() result(value)
    use lms_River_Aa
    implicit none
    integer :: value
    dll_export :: getSVClimateAdjustmentPercent
    real :: percentage

    percentage = gv_climatefactorSVT * 100.
    value = nint(percentage)
end function
subroutine setSVClimateAdjustmentPercent(value)
    use lms_River_Aa
    implicit none
    dll_export :: setSVClimateAdjustmentPercent
    integer :: value

    gv_climatefactorSVT=value * (1/100.)
end subroutine
!
! Drought factor start year
! ========
!
! C# interface = public override int SaltVerdeUserAdjustmentStartYear
!
function getSVUserAdjustmentStartYear() result(value)
    use lms_River_Aa
    implicit none
    dll_export :: getSVUserAdjustmentStartYear
    integer :: value

    value = gv_droughtyearSVT
end function
subroutine setSVUserAdjustmentStartYear(value)
    use lms_River_Aa
    implicit none
    dll_export :: setSVUserAdjustmentStartYear
    integer :: value

    gv_droughtyearSVT = value
end subroutine
!
! Drought factor stop year
! ============
! C# interface = public override int SaltVerdeUserAdjustmentStopYear
!
function getSVUserAdjustmentStopYear() result(value)
    use lms_River_Aa
    implicit none
    dll_export :: getSVUserAdjustmentStopYear
    integer :: value

    value = gv_droughtyearendSVT
end function
subroutine setSVUserAdjustmentStopYear(value)
    use lms_River_Aa
    implicit none
    dll_export :: setSVUserAdjustmentStopYear
    integer :: value

    gv_droughtyearendSVT = value
end subroutine
!
! Drought factor (proportional: 0 to > 1)
! ========
!
! C# interface = public override int SaltVerdeUserAdjustmentPercent
!
function getSVUserAdjustmentPercent() result(value)
    use lms_River_Aa
    implicit none
    dll_export :: getSVUserAdjustmentPercent
    integer :: value

    value = nint(gv_droughtfactorSVT*100.)
end function
subroutine setSVUserAdjustmentPercent(value)
    use lms_River_Aa
    implicit none
    dll_export :: setSVUserAdjustmentPercent
    integer :: value

    gv_droughtfactorSVT = value * 0.01
end subroutine
! ====================================

!
!----- Colorado River Input Variables ---------------------!
!
subroutine setCOtrace(value)
    use lms_River_Ba
    implicit none
    dll_export :: setCOtrace
    integer :: value

    gvi_COtrace = value
end subroutine
! 
! Runoff data set
! ===============
!
! C# interface = public override int ColoradoHistoricalData
!
function getCOHistData() result(value)
    use lms_River_ba
    implicit none
    dll_export :: getCOHistData
    integer :: value

    value=gv_dataCO

end function
subroutine setCOHistData(value)
    use lms_River_ba
    implicit none
    dll_export :: setCOHistData
    integer :: value

    gv_dataCO=1
    if(1 < value) gv_dataCO=value
end subroutine
!
! Index year
! ===============
!
! C# interface =  public override int ColoradoHistoricalExtractionStartYear
!
function getCOHistExtractionStartYear() result(value)
    use lms_River_ba
    implicit none
    integer :: value
    dll_export :: getCOHistExtractionStartYear

    value = gv_indexyearCO
end function
subroutine setCOHistExtractionStartYear(value)
    use lms_River_ba
    implicit none
    dll_export :: setCOHistExtractionStartYear
    integer :: value

   gv_indexyearCO=value
end subroutine
!
! Climate Factor
! ==============
!
! C# interface = public override int ColoradoClimateAdjustmentPercent
!
function getCOClimateAdjustmentPercent() result(value)
    use lms_River_Ba
    implicit none
    integer :: value
    real :: percentage
    dll_export :: getCOClimateAdjustmentPercent

    percentage= gv_climatefactorCO * 100.

    value = nint(percentage)
end function
subroutine setCOClimateAdjustmentPercent(value)
    use lms_River_Ba
    implicit none
    dll_export :: setCOClimateAdjustmentPercent
    integer :: value

    gv_climatefactorCO = value*0.01
end subroutine
!
! Drought year start
! ==================
!
! C# interface =  public override int ColoradoUserAdjustmentStartYear
!
function getCOUserAdjustmentStartYear() result(value)
    use lms_River_Ba
    implicit none
    integer :: value
    dll_export :: getCOUserAdjustmentStartYear

    value = gv_droughtyearCO
end function
subroutine setCOUserAdjustmentStartYear(value)
    use lms_River_Ba
    implicit none
    dll_export :: setCOUserAdjustmentStartYear
    integer :: value
    gv_droughtyearCO=2001
    if(0 < value)gv_droughtyearCO = value
end subroutine
!
! Drought year end
! ================
!
! C# interface =  public override int ColoradoUserAdjustmentStopYear
!
function getCOUserAdjustmentStopYear() result(value)
    use lms_River_Ba
    implicit none
    integer :: value
    dll_export :: getCOUserAdjustmentStopYear

    value = gv_droughtyearendCO
end function
subroutine setCOUserAdjustmentStopYear(value)
    use lms_River_Ba
    implicit none
    dll_export :: setCOUserAdjustmentStopYear
    integer :: value

    gv_droughtyearendCO = value
end subroutine
!
! Drought factor (proportional)
! ================
!
! C# interface =  public override int ColoradoUserAdjustmentPercent
!
function getCOUserAdjustmentPercent() result(value)
    use lms_River_Ba
    implicit none
    integer :: value
    dll_export :: getCOUserAdjustmentPercent

    value = nint(gv_droughtfactorCO * 100.)
end function
subroutine setCOUserAdjustmentPercent(value)
    use lms_River_Ba
    implicit none
    dll_export :: setCOUserAdjustmentPercent
    integer :: value

   gv_droughtfactorCO = value * 0.01
end subroutine
!----------------------------------------------------------!
!

!
!----- Policy Variables -----------------------------------!
!
! County-scale
! ============
!
function getWaterPolicy() result(value)
    use lm_GPdemand
    implicit none
    dll_export :: getWaterPolicy
    integer :: value

    value = gv_waterpolicy
end function
subroutine setWaterPolicy(value)
    use lm_GPdemand
    implicit none
    dll_export :: setWaterPolicy
    integer :: value

    gv_waterpolicy = value
end subroutine
!
! Start policy year
function getWaterPolicyStartYear() result(value)
    use lm_GPdemand
    implicit none
    dll_export :: getWaterPolicyStartYear
    integer :: value

    value = gv_WaterPolicyStartYear
end function
subroutine setWaterPolicyStartYear(value)
    use lm_GPdemand
    implicit none
    dll_export :: setWaterPolicyStartYear
    integer :: value

    gv_WaterPolicyStartYear = value
end subroutine
!
! Residential GPCD
! ================
function getResidentialGPCD() result(value)
    use lm_GPdemand
    implicit none
    dll_export :: getResidentialGPCD
    integer :: value

    value = go_residentialGPCD
end function
subroutine setResidentialGPCD(value)
    use lm_GPdemand
    implicit none
    dll_export :: setResidentialGPCD
    integer :: value

    gv_residentialGPCD = value
end subroutine
!
! Total GPCD
! ==========
function getTotalGPCD() result(value)
    use lm_GPdemand
    implicit none
    dll_export :: getTotalGPCD
    integer :: value

    value = gv_totalGPCD
end function
subroutine setTotalGPCD(value)
    use lm_GPdemand
    implicit none
    dll_export :: setTotalGPCD
    integer :: value

    gv_totalGPCD = value
end subroutine
!
! Density Path (1 to 3)
function getResidDensityPath() result(value)
    use lm_GPdemand
    implicit none
    dll_export :: getResidDensityPath
    integer :: value

    value = gv_resdensitypath
end function
subroutine setResidDensityPath(value)
    use lm_GPdemand
    implicit none
    dll_export :: setResidDensityPath
    integer :: value

    gv_resdensitypath = value
end subroutine
!
! Retire Agriculture in year x
function getAgricultureRetirementYear() result(value)
    use lm_GPdemand
    implicit none
    dll_export :: getAgricultureRetirementYear
    integer :: value

    value = gv_agretirementyear
end function
subroutine setAgricultureRetirementYear(value)
    use lm_GPdemand
    implicit none
    dll_export :: setAgricultureRetirementYear
    integer :: value

    gv_agretirementyear = value
end subroutine
!
! Proportion of households with pools
! ========
subroutine setPropPools(value)
    use lm_GPdemand
    implicit none
    dll_export :: setPropPools
    integer :: value

    gv_PropPools = value * (1/100.)
end subroutine
!
! Proportion of households with mesic landscaping
! ========
subroutine setPropMesic(value)
    use lm_GPdemand
    implicit none
    dll_export :: setPropMesic
    integer :: value

    gv_PropMesic = value * (1/ 100.)
end subroutine
!
! Shortage policy (Proportional Ag vs. Muni)
! ========
subroutine setShortagePolicy(value)
    use lm_GPdemand
    implicit none
    dll_export :: setShortagePolicy
    integer :: value

    gv_shortagepolicy = value
end subroutine
function getShortagePolicy() result(value)
    use lm_GPdemand
    implicit none
    dll_export :: getShortagePolicy
    integer :: value

    value = gv_shortagepolicy
end function
!
! Include natural recharge?
! ======
function getNaturalRechargeSwitch() result(value)
    use lm_Groundwater_A
    implicit none
    dll_export :: getNaturalRechargeSwitch
    logical :: value

    value = gv_rechargeNatural
end function
subroutine setNaturalRechargeSwitch(value)
    use lm_Groundwater_A
    implicit none
    dll_export :: setNaturalRechargeSwitch
    logical :: value

    gv_rechargeNatural = value
end subroutine
!
!

!
! -------- Population  -----------------------------------------------!
!
! Proportional change in population growth
! ======
!
! C# interface = public override int PopulationGrowthRateAdjustmentPercent
!
function getPopGrowthRateAdjustmentPct() result(value)
    use lms_GPdemand
!    use lms_Provider
    implicit none
    dll_export :: getPopGrowthRateAdjustmentPct
    integer :: value

    value = nint(gv_popgrowthfactor * 100)
end function
subroutine setPopGrowthRateAdjustmentPct(value)
    use lms_GPdemand
!    use lms_Provider
    implicit none
    dll_export :: setPopGrowthRateAdjustmentPct
    integer :: value

    gv_popgrowthfactor = value * (1/100.)
   
end subroutine
!
! Population of Maricopa Co.
! ======
function getPopMaricopa() result(value)
    use lm_GPdemand
    implicit none
    dll_export :: getPopMaricopa
    integer :: value

    value = gv_PopMaricopa
end function
!
!--------------------------------------------------------------------!
!
!
subroutine setPopFromInterface(value)
    use lms_GPdemand
!    use lms_Provider
    implicit none
    dll_export :: setPopGrowthRateAdjustmentPct
    integer :: value

    gv_popgrowthfactor = value * (1/100.)
   
end subroutine


! ====================================================================
!----- Annual Results Variables -------------------------------------!
!
! County-scale
! ============
!
function getAnnualMaricopaWaterDemand() result(value)
    use lms_GPdemand
    implicit none
    dll_export :: getAnnualMaricopaWaterDemand
    integer :: value
!
    value = go_maricopaWaterDemand
end function
!
function getAZshareCO() result(value)
    use lms_River_Ba
    implicit none
    dll_export :: getAZshareCO
    integer :: value
!
    value = go_AZshareCO
end function
!
function getCAP() result(value)
    use lms_River_Ba
    implicit none
    dll_export :: getCAP
    integer :: value
!
    value = go_CAP
end function
!
function getPowellElevation() result(value)
    use lms_River_Ba
    implicit none
    dll_export :: getPowellElevation
    integer :: value
!
    value = go_powellElevation
end function

function getMeadElevation() result(value)
    use lms_River_Ba
    implicit none
    dll_export :: getMeadElevation
    integer :: value
!
    value = go_meadElevation
end function
!
function getMeadElevationPredicted() result(value)
    use lms_River_Ba
    implicit none
    dll_export :: getMeadElevationPredicted
    integer :: value
!
    value = go_meadElevationPred
end function

!------------------------------------!
! annual outputs (some inputs)
!
!  Provider-scale
! ===============
! 
! 
! ========
! 
! C# interface= public int[] PopulationGrowthRateAdjustPct
!
subroutine getPopGrowthRateAdjustPct(count, values)
    use lms_Provider
    implicit none
    dll_export :: getPopGrowthRateAdjustPct
    integer :: count
    integer :: i
    integer, dimension(1:count) :: values

   forall(i=1:count) values(i) = nint(gv_PopGrowthRateAdjPct(i)*100.)
end subroutine
subroutine setPopGrowthRateAdjustPct(count, values)
    use lms_Provider
    implicit none
    dll_export :: setPopGrowthRateAdjustPct
    integer :: count,i
    integer, dimension(1:count) :: values
    real, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=1.
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i) * 0.01
    end forall
    !
   forall(i=1:count) gv_PopGrowthRateAdjPct(i)=generic(i) 

end subroutine
!
! C# interface= 
!





! Total water demand (Ag and Muni)
! ========
!
! C# interface=  public int[] WaterDemand 
!
subroutine getTotalDemands(count, values)
    use lms_Provider
    implicit none
    dll_export :: getTotalDemands
    integer :: count,i
    integer, dimension(1:count) :: values

   forall(i=1:count) values(i) = go_ProviderDemand(i)

end subroutine
!
! Provider populations
! ========
! 
! C# interface= public int[] Populations
!
subroutine getPopulations(count, values)
    use lms_Provider
    implicit none
    dll_export :: getPopulations
    integer :: count,i
    integer, dimension(1:count) :: values

   forall(i=1:count) values(i) = go_providerpop(i)

end subroutine
!
subroutine getPopGrowthRate(count, values)
    use lms_Provider
    implicit none
    dll_export :: getPopGrowthRate
    integer :: count,i
    integer, dimension(1:count) :: values

   forall(i=1:count) values(i) = go_PopGrowthRate(i)

end subroutine
!
subroutine setPopulations(count, values)
    use lms_Provider
    implicit none
    dll_export :: setPopulations
    integer :: count,i
    integer, dimension(1:count) :: values
    real, dimension(1:count) :: generic

    forall(i=1:count)generic(i)=0.
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i) 
    end forall

   forall(i=1:count) gi_ProviderPopulation(i) = generic(i) 

end subroutine
!

! actual provider water used (not in the API at all)
! ========
!
! C# interface =  public int[] ProviderWaterUsed 
!
subroutine getProviderDeliveriesUsed(count, values)
    use lms_Provider
    implicit none
    dll_export :: getProviderDeliveriesUsed
    integer :: count,i
    integer, dimension(1:count) :: values

   forall(i=1:count) values(i) = go_ProviderWaterUsed_acft(i)

end subroutine
!
!
!   
!  Colorado River Water
! ---------------------
! Delivered CAP water
! ========
!
! C# interface=  public override int[] ColoradoAnnualDeliveries 
!
subroutine getCOAnnualDeliveries(count, values)
    use lms_Provider
    implicit none
    dll_export :: getCOAnnualDeliveries
    integer :: count,i
    integer, dimension(1:count) :: values
    ! array = 35
    forall(i=1:count) values(i) = go_annualDeliveriesCO(i)

end subroutine
!
! C# interface=  public override int CAP2MandI
!
function getCAPMandI() result(value)
    use lms_Provider
    implicit none
    dll_export :: getCAPMandI
    integer :: value

    value = go_mandiCAP
end function
!
! Maximum CO - designations
! ================
!
! C# interface=  public override int[] ColoradoMaxDeliveries  
!
subroutine getCOMaxDeliveries(count, values)
   use lms_Provider
    implicit none
    dll_export :: getCOMaxDeliveries
    integer :: count,i
    integer, dimension(1:count) :: values

    forall(i=1:count) values(i) = go_maxDeliveriesCO(i)
end subroutine
!


! New variable, not yet implemented
! Will be used to contain "extra" CAP allocations
! 12.15.11 DAS
!subroutine getCOAddDeliveries(count, values)
!    use  lms_Designations_B
!    implicit none
!    dll_export :: getCOAddDeliveries
!    integer :: count,i
!    integer, dimension(1:count) :: values
!    ! array = 35
!    !forall(i=1:count) values(i) = go_addDeliveriesCO(i)
!
!end subroutine
!subroutine setCOAddDeliveries(count, values)
!    use  lms_Designations_B
!    implicit none
!    dll_export :: setCOAddDeliveries
!    integer :: count,i
!    integer, dimension(1:count) :: values
!    ! array = 35
!    !forall(i=1:count) = go_addDeliveriesCO(i)=values(i) 
!
!end subroutine
! 
! SVT
! ========
!  Class A,B,C, and NCS for the 10
! ========
!
! C# interface=public override int[] SVTAnnualDeliveriesSRP
!
subroutine getSRPAnnualDeliveries(count, values)
    use lms_Provider
    implicit none
    dll_export :: getSRPAnnualDeliveries
    integer :: count,i
    integer, dimension(1:count) :: values

    forall(i=1:count) values(i) =go_annualDeliveriesSRP(i)
end subroutine
!
! Maxmum class A,B,C, and NCS scaled to 10
!
! C# interface= public override int[] SaltVerdeMaxDeliveries   
!
subroutine getSVMaxDeliveriesSRP(count, values)
    use lms_Provider
    implicit none
    dll_export :: getSVMaxDeliveriesSRP
    integer :: count,i
    integer, dimension(1:count) :: values

    forall(i=1:count) values(i)=go_maxDeliveriesSRP(i)

end subroutine
!
! Designations class A, scaled to 10
! ====================
! C# interface =  public override int[] SaltVerdeClassADesignationsUsed  
!
subroutine getSVClassADesignations(count, values)
    use lms_Provider
    implicit none
    dll_export :: getSVClassADesignations
    integer :: count,i
    integer, dimension(1:count) :: values

    forall(i=1:count) values(i)=go_classAdesignations(i)
end subroutine
!
! Maimum class A
! ================
! C# interface =  public override int[] SaltVerdeClassAmax 
!
subroutine getSVClassAmax(count, values)
    use lms_Provider
    implicit none
    dll_export :: getSVClassAmax
    integer :: count,i
    integer, dimension(1:count) :: values

    forall(i=1:count) values(i)= go_classAmax(i)
end subroutine
!
! SRP pumping desig
! ==============
! C# interface=  public int[] SaltVerdeClassBCDesignations  
!
subroutine getSVClassBCDesignations(count, values)
    use lms_Provider
    implicit none
    dll_export :: getSVClassBCDesignations
    integer :: count,i
    integer, dimension(1:count) :: values

    forall(i=1:count) values(i)= go_classBCdesignations(i)
end subroutine
! 
! Maximum B&C by SRP
! ===============
! C# interface =  public int[] SaltVerdeClassBCmax 
!
subroutine getSVClassBCmax(count, values)
    use lms_Provider
    implicit none
    dll_export :: getSVClassBCmax
    integer :: count,i
    integer, dimension(1:count) :: values

    forall(i=1:count) values(i)= go_classBCmax(i)
end subroutine
! 

! New Conservation Space, scaled to 33
! ========
! C# interface = public int[] SaltVerdeNCSDesignations 
!
subroutine getSVNCS(count, values)
    use lms_Provider
    implicit none
    dll_export :: getSVNCS
    integer :: count,i
    integer, dimension(1:count) :: values
    ! brought from 7 to 10 in model
    forall(i=1:count) values(i)=go_NCS_acft(i)
end subroutine
!
! C# interface=  public int[] SaltVerdeNCSmax  
!
subroutine getSVNCSmax(count, values)
    use  lms_Provider
    implicit none
    dll_export :: getSVNCSmax
    integer :: count,i
    integer, dimension(1:count) :: values
    ! brought from 7 to 10 in model
    forall(i=1:count) values(i)=go_NCSmax_acft(i)
end subroutine
! 
! New B and C water removed from storage (reservoir)
! currently not in the API as of 02.10.12
! ========
! C# interface = public int[] 
!
subroutine getSVTclassBCstorage(count, values)
    use lms_Provider
    implicit none
    dll_export :: getSVTclassBCstorage
    integer :: count,i
    integer, dimension(1:count) :: values
    ! brought from 7 to 10 in model
    forall(i=1:count) values(i)=goi_classBCstorage_acft(i)
end subroutine
!
! C# interface=  public int[]  
!
subroutine getSVTclassBCstorageMax(count, values)
    use  lms_Provider
    implicit none
    dll_export :: getSVTclassBCstorageMax
    integer :: count,i
    integer, dimension(1:count) :: values
    ! brought from 7 to 10 in model
    forall(i=1:count) values(i)=goi_classBCstorageMax_acft(i)
end subroutine

! 
!   ---------------------------------
!         General Variables

! Available to pump legally
! ==============
! C# interface =  public override int[] ProviderGWdesignations 
! 
subroutine getProviderGWDesignations(count, values)
    use lms_Provider
    implicit none
    dll_export :: getProviderGWDesignations
    integer :: count,i
    integer, dimension(1:count) :: values

    forall(i=1:count) values(i)= vDesignationsGW(i)
end subroutine
!
! 02.10.12
! Legal surface water designations based on storage and flow (includes reservoir water)
! ==============
! C# interface =    public override int[] ProviderSWdesignations 
!
subroutine getProviderSWDesignations(count, values)
    use lms_Provider
    implicit none
    dll_export :: getProviderSWDesignations
    integer :: count,i
    integer, dimension(1:count) :: values

    forall(i=1:count) values(i)= go_SWdesignations_acft(i)
end subroutine
!
!
! ==============================================================
!
! Alternate variables  
!
!   Water use after subtracting grey water recycling from demand
!
subroutine getProviderPostReclaimedUse(count, values)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: getProviderPostReclaimedUse
    integer :: count,i
    integer, dimension(1:count) :: values

    forall(i=1:count) values(i)= go_ProviderPostReclaimed(i)
end subroutine
!
!  Provider GPCD and water Demand OPTIONS
!subroutine getProviderGPCD(count, values)
!    use lms_Provider
!    implicit none
!    dll_export :: getProviderGPCD
!    integer :: count,i
!    integer, dimension(1:count) :: values
!
!    forall(i=1:count) values(i)= go_providersGPCD(i)
!end subroutine
!
! C#  public  int[] ProviderGPCD
!
subroutine setProviderGPCD(count, values)
    use lms_ProviderPopandDemand 
    implicit none
    dll_export :: setProviderGPCD
    integer :: count,i
    integer, dimension(1:count) :: values    
    real, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=0.
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i) 
    end forall
    !
    forall(i=1:count) gv_AdjustedGPCD(i)= generic(i)
end subroutine
!
subroutine getProviderGPCD(count, values)
    use lms_Provider
    implicit none
    dll_export :: getProviderGPCD
    integer :: count,i
    integer, dimension(1:count) :: values

    forall(i=1:count) values(i)= goi_SES_GPCD(i)
    ! Provider.f90 line 796
end subroutine
!

! =======================================
!
!
!----- Colorado Variables --------------!
!
! CO flow
! =============
! C# interface = public override int ColoradoRiverFlow
!
function getCORiverFlow() result(value)
    use lms_River_Ba
    implicit none
    dll_export :: getCORiverFlow
    integer :: value

    value = go_riverFlowCO

end function
!
! CO storage
! =============
! C# interface = public override int ColoradoStorage
!
function getCOStorage() result(value)
    use lms_River_Ba
    implicit none
    dll_export :: getCOStorage
    integer :: value

    value = go_StateCO
end function
!
! Powell reservoir
! =============
! C# interface =  public override int PowellStorage
!
function getPowellStorage() result(value)
    use lms_River_Ba

    implicit none
    dll_export :: getPowellStorage
    integer :: value

    value = go_StatePowell
end function
!
! Mead reservoir
! =============
! C# interface =  public override int MeadStorage
!
function getMeadStorage() result(value)
    use lms_River_Ba
    implicit none
    dll_export :: getMeadStorage
    integer :: value

    value = go_StateMead
end function
!
!
! =============
! C# interface =
!
function getCODelivery() result(value)
    use lms_WaterShed
    implicit none
    dll_export :: getCODelivery
    integer :: value

    value = go_deliveriesCO
end function
!
!
!
!----- Salt/Verde Variables -------------------------------!
!
! SRP release
! =============
! C# interface =  public override int SaltVerdeDelivery
!
function getSVDelivery() result(value)
    use lms_WaterShed
    implicit none
    dll_export :: getSVDelivery
    integer :: value

    value = go_deliveriesSVT
end function
!
! SVT flow (modified by factors)
! =============
! C# interface =   public override int SaltVerdeRiverFlow
!
function getSVRiverFlow() result(value)
    use lms_River_Aa
    implicit none
    dll_export :: getSVRiverFlow
    integer :: value

    value = go_riverFlowSVT
end function
!
! Total Reservoir storage
! =======================
!
! C# interface =  public override int SaltVerdeStorage
!
function getSVStorage() result(value)
    use lms_River_Aa
    implicit none
    dll_export :: getSVStorage
    integer :: value

    value = go_StateSVT
end function
! Total Reservoir storage
! =======================
!
! C# interface = 
!
function getSVTspillage() result(value)
    use  lms_SRPrelease
    implicit none
    dll_export :: getSVTspillage
    integer :: value

    value = go_spillageSVT
end function

!
!----------------------------------------------------------!
!----- Groundwater Variables ------------------------------!
!
! County-scale
! ============
function getGroundwaterState() result(value)
    use lm_Groundwater_A
    implicit none
    dll_export :: getGroundwaterState
    integer :: value

    value = go_StateGW
end function
!
function getGroundwaterPumpage() result(value)
    use lms_Groundwater_A
    implicit none
    dll_export :: getGroundwaterPumpage
    integer :: value

    value = go_PumpageGW
end function
!
function getGroundwaterRecharge() result(value)
    use lms_Groundwater_A
    implicit none
    dll_export :: getGroundwaterRecharge
    integer :: value

    value = go_RechargeGW
end function
!
function getGroundwaterDiff() result(value)
    use lms_Groundwater_A
    implicit none
    dll_export :: getGroundwaterDiff
    integer :: value

    value = go_groundwaterDifference
end function
!

function getNaturalRecharge() result(value)
    use lms_Groundwater_A
    implicit none
    dll_export :: getNaturalRecharge
    integer :: value

    value = go_naturalRecharge
end function
!
! ----------------------------------------
!  Provider-based
! ===============
!
!  Groundwater
! -------------------------
!  IN: subroutine sAquifer()
!
! CityModel groundwater estimates
! =============
! C# interface =  public override int[] ProviderGroundwater
!
subroutine getAnnualProviderGroundW(count, values)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: getAnnualProviderGroundW
    integer :: count,i
    integer, dimension(1:count) :: values
    !
    forall(i=1:count) values(i)= go_ProviderGroundWater_a(i)
    ! line 409 in Water_CitiModel.f90
end subroutine
!
subroutine setProviderGroundWater(count, values)
    use lms_WaterShed
    implicit none
    dll_export :: setProviderGroundWater
    integer :: count,i
    integer, dimension(1:count) :: values
    integer, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=1
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i) 
    end forall
    !
    forall(i=1:count) gvi_ProviderGroundWater_a(i)=generic(i)
    ! 
end subroutine

! IN: subroutine aDemandSupply()
!
! Municipal pumping
! =============
! C# interface = public override int[] ProviderGWPumpedMunicipal 
!
subroutine getProviderGWPumpageMuni(count, values)
    use lms_Provider
    implicit none
    dll_export :: getProviderGWPumpageMuni
    integer :: count,i
    integer, dimension(1:count) :: values

   forall(i=1:count) values(i) = go_GWPumpageMuni_acft(i)

end subroutine
!
! C# interface =  public void BCtoSRP()
!                 used as int[] ProviderGWPumpedSRP 
subroutine getProviderGWPumpageSRP(count, values)
    use lms_Provider
    implicit none
    dll_export :: getProviderGWPumpageSRP
    integer :: count,i
    integer, dimension(1:count) :: values

   forall(i=1:count) values(i) = go_GWPumpageSRP_acft(i)

end subroutine
!
! C# interface=   public override int[] ProviderGWRecharge  
!                
subroutine getProviderGWRecharge(count, values)
    use lms_Provider
    implicit none
    dll_export :: getProviderGWRecharge
    integer :: count,i
    integer, dimension(1:count) :: values

   forall(i=1:count) values(i) = go_GWRecharge_acft(i)

end subroutine
!
! 
!
!
! CityModel Outputs
! =================
!

! =================
! C# interface = 
!

! =============================================================================!
! -----------------------------------------------------------------------------!
! Special Projects
! ===============

! Provider.f90 - using SES reduces GPCD by x% by the year 2100
subroutine setReductionGPCDPct(value)
    use lms_ProviderPopandDemand
    implicit none
    dll_export :: setReductionGPCDPct
    integer :: value
    !
    gvi_ReductionGPCD_pct = value
    !
end subroutine
!

! Water_CityModel.f90 - using SES reduces outdoor water use x% by the year 2100
subroutine setReductionResPct(value)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: setReductionResPct
    integer :: value
    !
    lvf_OutdoorResUse_ReducePct = value
    !
end subroutine
!
! ----------------------------------------------

! --------------------------------------------------------------
!
! Energy variables
! ----------------
!
function getCAPEnergyUsedInPumping() result(value)
    use mEnergyCAP
    implicit none
    dll_export :: getCAPEnergyUsedInPumping
    integer :: value

    value = go_energyusedinpumpingCAP
end function
!



! ==========================================================================!
! --------------------------------------------------------------------------!
!
!  Provider Inputs
!
! Water demand options
! 1=read from file
! 2=six year average GPCD
! 3=uses simple exponential smoothing of GPCD and population
! 4=not implemented
!
! =================
!
! C# interface =    public override int ProviderDemandOption
!
subroutine setDemandOption(value)
    use lms_ProviderPopandDemand
    implicit none
    dll_export :: setDemandOption
    integer :: value

   gvi_ProviderDemandOption=value

end subroutine
function getDemandOption() result(value)
    use lms_ProviderPopandDemand
    implicit none
    dll_export :: getDemandOption
    integer :: value

   value = gvi_ProviderDemandOption

end function
!
subroutine getWaterBankingOption(count, values)
    use lms_Provider
    implicit none
    dll_export :: getWaterBankingOption
    integer :: count,i
    integer, dimension(1:count) :: values
    forall(i=1:count) values(i)=   gvi_WBankingOption(i)
end subroutine
subroutine setWaterBankingOption(count,values)
    use lm_ParameterControl
    implicit none
    dll_export :: setWaterBankingOption
    integer :: count,i
    integer, dimension(1:count) :: values
    integer, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=1
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i) 
    end forall
    !
    forall(i=1:count) gvi_WBankingOption(i)=generic(i)
end subroutine

! Reduce water demand
! =================
!
! C# interface = public int DemandPercent
!
subroutine setDemandPercent(value)
    use lms_ProviderPopandDemand
    implicit none
    dll_export :: setDemandPercent
    integer :: value

   gvi_ReductionDemand_pctOfBaseline=value

end subroutine
function getDemandPercent() result(value)
    use lms_ProviderPopandDemand
    implicit none
    dll_export :: getDemandPercent
    integer :: value

   value = gvi_ReductionDemand_pctOfBaseline

end function


! From line 452 ProviderPopulationandDemand.f90
! Item 70
! Special Projects
! -----------------------------------------------
!
! C# interface =   public float TemperatureMultiplier
!
subroutine getDemandMultiplier(value)
    use lms_ProviderPopandDemand
    implicit none
    dll_export :: getDemandMultiplier
    integer :: value
    ! note: X 1000 to retain thousandths place
   value = nint(gvf_ResponseToTemperature*1000)

end subroutine
!
!function getGrowthMultiplier() result(value
!    use lms_ProviderPopandDemand
!    implicit none
!    dll_export :: getGrowthMultiplier
!    integer :: value
!    ! note: X 1000 to retain thousandths place
!   value = nint(gvf_ResponseToGrowth*1000)
!
!end function
!
!
subroutine getOnProjectDemand(count, values)
    use lms_Provider
    implicit none
    dll_export :: getOnProjectDemand
    integer :: count,i
    integer, dimension(1:count) :: values

   forall(i=1:count) values(i) = go_OnProjectDemand(i)

end subroutine
!
subroutine getOffProjectDemand(count, values)
    use lms_Provider
    implicit none
    dll_export :: getOffProjectDemand
    integer :: count,i
    integer, dimension(1:count) :: values

   forall(i=1:count) values(i) = go_OffProjectDemand(i)

end subroutine
!
! -----------------------------------------------
!
! This code uses SES to reduce the SVT climate factor temporally
! It uses a 40-year period to reach target level: more realistic than
! over-night changing flow rates...
! -------------------------------------
subroutine setReducePercentSVTcf(value)
    use lms_River_Aa
    implicit none
    dll_export :: setReducePercentSVTcf
    integer :: value

   gvi_SVT_SES_reducePct=value

end subroutine
!

! NOT implemented-will adjust model estimates
! based on MODFLOW estimates
! ----------------------------------------------
!subroutine setProviderGroundwater(count, values)
!    use lms_CitiWaterBudgets
!    implicit none
!    dll_export :: setProviderGroundwater
!    integer :: count,i
!    integer, dimension(1:count) :: values
!
!    forall(i=1:count) gv_providerGWFromInterface(i)=values(i)*1. 
!end subroutine
!
! --------------------------------------------------------------- TO BE REMOVED
!   Zero to 100 pct: how much grey water recycled each time step
! 
subroutine setResidentialGWusePct(count, values)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: setResidentialGWusePct
    integer :: count,i
    integer, dimension(1:count) :: values

    forall(i=1:count) gvf_RateGreyWaterRES(i)=values(i)*0.01 
end subroutine
!
!   Zero to 100 pct: how much grey water recycled each time step
subroutine setCommercialIOGWusePct(count, values)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: setCommercialIOGWusePct
    integer :: count,i
    integer, dimension(1:count) :: values

    forall(i=1:count) gvf_RateGreyWaterCIO(i)=values(i)* (1/100.)

end subroutine
! -----------------------------------------------------------------
!


!
! =============================================================================
! -----------------------------------------------------------------------------
!
! Set/get CityModel parameters (inputs)
!
! ==============
! 
! Generic Policy 
!
! ------------------
!
! Time lag for water to move through the 
!
! ==============
! C# interface =  public int[] get_parmReclaimedToVadosePct
!
subroutine getTimeLagVadoseYears(count, values)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: getTimeLagVadoseYears
    integer :: count,i
    integer, dimension(1:count) :: values
    forall(i=1:count) values(i)=  gvi_timeLagVadose(i)
end subroutine
subroutine setTimeLagVadoseYears(mydefault, count, values)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: setTimeLagVadoseYears
    integer :: mydefault,count,i
    integer, dimension(1:count) :: values
    integer, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=mydefault
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i) 
    end forall
    !
    forall(i=1:count)  gvi_timeLagVadose(i)=generic(i)
end subroutine
! ----------------------------------------------------------
!


! ----------------------------------------------------------
! C# interface =  public int[] get_parmReclaimedToVadosePct
!
subroutine getParmReclaimedToVadosePct(count, values)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: getParmReclaimedToVadosePct
    integer :: count,i
    integer, dimension(1:count) :: values
    forall(i=1:count) values(i)=  nint(gvf_parm_RtoVadose(i)*100.)
end subroutine
subroutine setParmReclaimedToVadosePct(count, values)
    use lm_ParameterControl
    implicit none
    dll_export :: setParmReclaimedToVadosePct
    integer :: count,i
    integer, dimension(1:count) :: values
    real, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=0.0
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i) * 0.01
    end forall
    !
    forall(i=1:count) gvf_parm_RtoVadose(i)= generic(i)
end subroutine
! --------------------------------------------------
!
!
! ==============
! C# interface =  public int[] get_parmReclaimedToDirectInjectPct
!
subroutine getParmReclaimedToDirectInjPct(count, values)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: getParmReclaimedToDirectInjPct
    integer :: count,i
    integer, dimension(1:count) :: values
    forall(i=1:count) values(i)=   nint(gvf_parm_RtoDInjection(i)*100.)
end subroutine
subroutine setParmReclaimedToDirectInjPct(count, values)
    use lm_ParameterControl
    implicit none
    dll_export :: setParmReclaimedToDirectInjPct
    integer :: count,i
    integer, dimension(1:count) :: values
    real, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=0.
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i) * 0.01
    end forall
    !
    forall(i=1:count) gvf_parm_RtoDInjection(i)= generic(i)
end subroutine
! --------------------------------------------------
!


! --------------------------------------------------

!
! ==============
! C# interface =  public int[] get_parmReclaimedToOutputPct
!
subroutine getParmReclaimedToOutputPct(count, values)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: getParmReclaimedToOutputPct
    integer :: count,i
    integer, dimension(1:count) :: values
    forall(i=1:count) values(i)=   nint(gvf_parm_RtoOutput(i)*100.)
end subroutine
subroutine setParmReclaimedToOutputPct(mydefault,count, values)
    use lm_ParameterControl
    implicit none
    dll_export :: setParmReclaimedToOutputPct
    integer :: mydefault,count,i
    integer, dimension(1:count) :: values
    real, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=mydefault*0.01
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i) * 0.01
    end forall
    !
    forall(i=1:count) gvf_parm_RtoOutput(i)= generic(i)
end subroutine
! ------------------------------------------------
!

!
! ==============
! C# interface =  public int[] get_parmReclaimedToOutputPct
!
subroutine getParmReclaimedToInputPct(count, values)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: getParmReclaimedToInputPct
    integer :: count,i
    integer, dimension(1:count) :: values
    forall(i=1:count) values(i)=   nint(gvf_parm_RtoInputMaxPct(i)*100.)
end subroutine
subroutine setParmReclaimedToInputPct(mydefault,count, values)
    use lm_ParameterControl
    implicit none
    dll_export :: setParmReclaimedToInputPct
    integer :: mydefault,count,i
    integer, dimension(1:count) :: values
    real, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=mydefault*0.01
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i) * 0.01
    end forall
    !
    forall(i=1:count) gvf_parm_RtoInputMaxPct(i)= generic(i)
end subroutine
! ------------------------------------------------






! ==============
! C# interface =  public int[] get_parmReclaimedOutdoorUsePct
!
subroutine getReclaimedOutdoorUse(count, values)
   use lms_CitiWaterBudgets
    implicit none
    dll_export :: getReclaimedOutdoorUse
    integer :: count,i
    integer, dimension(1:count) :: values
    ! 
    forall(i=1:count) values(i)=   gvf_parm_ReclaimedOutdoor(i)*100
end subroutine
subroutine setReclaimedOutdoorUse(mydefault,count, values)
    use lm_ParameterControl
    implicit none
    dll_export :: setReclaimedOutdoorUse
    integer :: mydefault,count,i
    integer, dimension(1:count) :: values
    real, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=mydefault*0.01
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i) * 0.01
    end forall
    !
    forall(i=1:count)  gvf_parm_ReclaimedOutdoor(i)= generic(i)
end subroutine
! --------------------------------------------------
!
!
! ==============
! C# interface =  
!
! --------------------------------------------------
!
!
! ==============
! C# interface = public int[] get_parmReclaimedWWtoROPct
!
subroutine getParmRWWToROPct(count, values)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: getParmRWWToROPct
    integer :: count,i
    integer, dimension(1:count) :: values
    forall(i=1:count) values(i)=   nint(gvf_parm_RWWtoRO(i)*100.)
end subroutine
subroutine setParmRWWToROPct(count, values)
    use lm_ParameterControl
    implicit none
    dll_export :: setParmRWWToROPct
    integer :: count,i
    integer, dimension(1:count) :: values
    real, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=0.
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i) * 0.01
    end forall
    !
    forall(i=1:count) gvf_parm_RWWtoRO(i)=generic(i)
end subroutine
! --------------------------------------------------
!
!
! ==============
! C# interface =  public int[] get_parmROReclaimedToOutputPct
!
subroutine getParmROToOutputPct(count, values)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: getParmROToOutputPct
    integer :: count,i
    integer, dimension(1:count) :: values
    forall(i=1:count) values(i)=   nint(gvf_parm_ROtoOutput(i)*100.)
end subroutine
subroutine setParmROToOutputPct(mydefault,count, values)
    use lm_ParameterControl
    implicit none
    dll_export :: setParmROToOutputPct
    integer :: mydefault,count,i
    integer, dimension(1:count) :: values
   real, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=mydefault*0.01
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i) * 0.01
    end forall
    !
    forall(i=1:count) gvf_parm_ROtoOutput(i)=  generic(i)
end subroutine
! --------------------------------------------------
!
!
! ==============
! C# interface =  public int[] get_parmOutdoorWaterUsePct
!
subroutine getParmOutDoorPct(count, values)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: getParmOutDoorPct
    integer :: count,i
    integer, dimension(1:count) :: values
    ! really a proportion
    forall(i=1:count) values(i)=   nint(gvf_parm_OutDoorProp(i)*100.)
end subroutine
subroutine setParmOutDoorPct(mydefault,count, values)
    use lm_ParameterControl
    implicit none
    dll_export :: setParmOutDoorPct
    integer :: mydefault,count,i
    integer, dimension(1:count) :: values
    real, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=mydefault*0.01
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i) * 0.01
    end forall
    !
    forall(i=1:count) gvf_parm_OutDoorProp(i)= generic(i)
end subroutine
! --------------------------------------------------
!
!
! ==============
! C# interface = public int[] get_parmWaterSupplyToResidentialPct
!
subroutine getParmWStoResPct(count, values)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: getParmWStoResPct
    integer :: count,i
    integer, dimension(1:count) :: values
    ! really a proportion
    forall(i=1:count) values(i)=   nint(gvf_parm_WStoRes_prop(i)*100.)
end subroutine
subroutine setParmWStoResPct(mydefault,count, values)
    use lm_ParameterControl
    implicit none
    dll_export :: setParmWStoResPct
    integer :: mydefault,count,i
    integer, dimension(1:count) :: values
    real, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=mydefault*0.01
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i) * 0.01
    end forall
    !
    forall(i=1:count) gvf_parm_WStoRes_prop(i)= generic(i)
end subroutine
! --------------------------------------------------
!
!
! ==============
! C# interface =  public int[] get_parmWaterSupplyToCIOpct
!
subroutine getParmWStoCioPct(count, values)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: getParmWStoCioPct
    integer :: count,i
    integer, dimension(1:count) :: values
    ! really a proportion
    forall(i=1:count) values(i)=   nint(gvf_parm_WStoCio_prop(i)*100.)
end subroutine
subroutine setParmWStoCioPct(mydefault,count, values)
    use lm_ParameterControl
    implicit none
    dll_export :: setParmWStoCioPct
    integer :: mydefault,count,i
    integer, dimension(1:count) :: values
    real, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=mydefault*0.01
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i) * 0.01
    end forall
    !
    forall(i=1:count) gvf_parm_WStoCio_prop(i)= generic(i)
end subroutine
! --------------------------------------------------
!
!
! ==============
! C# interface = public int[] get_parmWWtoRWWTPpct
!
subroutine getParmWWtoRWWTPPct(count, values)
    use lms_CitiWaterBudgets 
    implicit none
    dll_export :: getParmWWtoRWWTPPct
    integer :: count,i
    integer, dimension(1:count) :: values
    ! really a proportion
    forall(i=1:count) values(i)=   nint(gvf_parm_WWtoRWWTP(i)*100.)
end subroutine
subroutine setParmWWtoRWWTPPct(count,values)
    use lm_ParameterControl
    implicit none
    dll_export :: setParmWWtoRWWTPPct
    integer :: count,i
    integer, dimension(1:count) :: values
    real, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=0.
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i) * 0.01
    end forall
    !
    forall(i=1:count) gvf_parm_WWtoRWWTP(i)=generic(i)
end subroutine
! --------------------------------------------------

!
! ==============
! C# interface = public int[] get_setParmWWtoRWWTPPct_setParmWWtoRWWTPPct_parmWWtoEffluentPct
!
subroutine getParmWWtoEffluentPct(count, values)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: getParmWWtoEffluentPct
    integer :: count,i
    integer, dimension(1:count) :: values
    ! really a proportion
    forall(i=1:count) values(i)=   nint(gvf_parm_WWtoEffluent(i)*100.)
end subroutine
subroutine setParmWWtoEffluentPct(mydefault,count, values)
    use lm_ParameterControl
    implicit none
    dll_export :: setParmWWtoEffluentPct
    integer :: mydefault,count,i
    integer, dimension(1:count) :: values
    real, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=mydefault*0.01
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i) * 0.01
    end forall
    !
    forall(i=1:count) gvf_parm_WWtoEffluent(i)=generic(i)
    !
end subroutine
! --------------------------------------------------
!
!
! ==============
! C# interface =  public int[] get_parmSurfaceWaterToWBankPct
!
subroutine getParmSWtoWBankPct(count, values)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: getParmSWtoWBankPct
    integer :: count,i
    integer, dimension(1:count) :: values
    ! really a proportion
    forall(i=1:count) values(i)=   nint(gvf_parm_SWtoWB(i)*100.)
end subroutine

subroutine setParmSWtoWBankPct(count, values)
    use lms_Provider
    implicit none
    dll_export :: setParmSWtoWBankPct
    integer :: count,i
    integer, dimension(1:count) :: values
    real, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=0.
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i) * 0.01
    end forall
    !
    forall(i=1:count) gvf_parm_SWtoWB(i)= generic(i)

end subroutine
! --------------------------------------------------
!
! ==============
! C# interface =  public int[] get_parmSurfaceWaterToWBankAmt
!
subroutine getParmSWtoWBankAmt(count, values)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: getParmSWtoWBankAmt
    integer :: count,i
    integer, dimension(1:count) :: values
    ! really a proportion
    forall(i=1:count) values(i)=  nint(gvf_parm_SWtoWBamount(i))
end subroutine
subroutine setParmSWtoWBankAmt(mydefault,count, values)
    use lm_ParameterControl
    implicit none
    dll_export :: setParmSWtoWBankAmt
    integer :: mydefault,count,i
    integer, dimension(1:count) :: values
    real, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=mydefault
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i)*1.
    end forall
    !
    forall(i=1:count) gvf_parm_SWtoWBamount(i)= generic(i)
end subroutine setParmSWtoWBankAmt
! --------------------------------------------------------
!

! ==============
! C# interface =  public int[] get_parmSurfaceWaterToVadoseAmt
!
subroutine getParmSWtoVadoseAmt(count, values)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: getParmSWtoVadoseAmt
    integer :: count,i
    integer, dimension(1:count) :: values
    ! really a proportion
    forall(i=1:count) values(i)=  nint(gvf_parm_SWtoVadoseAmt(i))
end subroutine
subroutine setParmSWtoVadoseAmt(mydefault,count, values)
    use lm_ParameterControl
    implicit none
    dll_export :: setParmSWtoVadoseAmt
    integer :: mydefault,count,j
    integer, dimension(1:count) :: values
    real, dimension(1:count) :: generic
    !
    forall(j=1:count)generic(j)=mydefault
    forall(j=1:count, values(j) .ne. -1)
      generic(j) = values(j)*1.
    end forall
    !
    forall(j=1:count) gvf_parm_SWtoVadoseAmt(j)= generic(j)
end subroutine setParmSWtoVadoseAmt
! --------------------------------------------------
!
! ==============
! C# interface =  public int[] get_parmSurfaceWaterToDIAmt
!
subroutine getParmWStoDIAmt(count, values)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: getParmWStoDIAmt
    integer :: count,i
    integer, dimension(1:count) :: values
    ! really a proportion
    forall(i=1:count) values(i)=  nint(gvf_parm_WStoDIamount(i))
end subroutine
subroutine setParmWStoDIAmt(mydefault,count, values)
    use lm_ParameterControl
    implicit none
    dll_export :: setParmWStoDIAmt
    integer :: mydefault,count,i
    integer, dimension(1:count) :: values
    real, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=mydefault
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i)*1.
    end forall
    !
    forall(i=1:count) gvf_parm_WStoDIamount(i)= generic(i)
end subroutine
! --------------------------------------------------





!
! ==============
! C# interface =  public int[] get_parmEffluenttoPowerPlantPct
!
subroutine getParmEffluentToPPlantPct(count, values)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: getParmEffluentToPPlantPct
    integer :: count,i
    integer, dimension(1:count) :: values
    ! really a proportion
    forall(i=1:count) values(i)=   nint(gvf_parm_EffluenttoPP(i)*100.)
end subroutine
subroutine setParmEffluentToPPlantPct(count, values)
    use lm_ParameterControl
    implicit none
    dll_export :: setParmEffluentToPPlantPct
    integer :: count,i
    integer, dimension(1:count) :: values
    real, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=0.0
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i) * 0.01
    end forall
 
    forall(i=1:count) gvf_parm_EffluenttoPP(i)= generic(i)
end subroutine
! --------------------------------------------------
!
!
! ==============
! C# interface =  public int[] parm_CModelEffluenttoVadosePct
!
subroutine getParmEffluenttoVadosePct(count, values)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: getParmEffluenttoVadosePct
    integer :: count,i
    integer, dimension(1:count) :: values
    ! really a proportion
    forall(i=1:count) values(i)=   nint(gvf_parm_EffluentToVadose(i)*100.)
end subroutine
subroutine setParmEffluenttoVadosePct(count, values)
    use lm_ParameterControl
    implicit none
    dll_export :: setParmEffluenttoVadosePct
    integer :: count,i
    integer, dimension(1:count) :: values
    real, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=0.0
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i) * 0.01
    end forall
    !
    forall(i=1:count) gvf_parm_EffluentToVadose(i)= generic(i)
end subroutine
! --------------------------------------------------
!
!
! ==============
! C# interface =  public int[] parm_CModelGroundwaterToGWTPlantPct
!
subroutine getParmGWtoGWTPPct(count, values)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: getParmGWtoGWTPPct
    integer :: count,i
    integer, dimension(1:count) :: values
    ! really a proportion
    forall(i=1:count) values(i)=   nint(gvf_parm_GWtoGWTP(i)*100.)
end subroutine
subroutine setParmGWtoGWTPPct(count, values)
    use lm_ParameterControl
    implicit none
    dll_export :: setParmGWtoGWTPPct
    integer :: count,i
    integer, dimension(1:count) :: values
    real, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=0.0
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i) * 0.01
    end forall
    !
    forall(i=1:count) gvf_parm_GWToGWTP(i)= generic(i)
end subroutine
! --------------------------------------------------
!


subroutine setParmIncludeMeteo(value)
    use lm_ParameterControl
    implicit none
    dll_export :: setParmIncludeMeteo
    logical :: value
    !
    gvl_IncludeMeteorology=.false.
    if(value)gvl_IncludeMeteorology = value
    !
end subroutine
! --------------------------------------------------
!


! ==================================================
! CityModel Outputs
!

! ==============
! C# interface =   public int[] GroundwaterBankUsed 
!
subroutine getGWbankedUsed(count, values)
   use lms_CitiWaterBudgets
    implicit none
    dll_export :: getGWbankedUsed
    integer :: count,i
    integer, dimension(1:count) :: values
    ! 
    forall(i=1:count) values(i)=  goi_GWBankUsed_AF(i) 
end subroutine
! --------------------------------------------------
!
! ==============
! C# interface =   public int[] GroundwaterBankBalance  
!
subroutine getGWbanked(count, values)
   use lms_CitiWaterBudgets
    implicit none
    dll_export :: getGWbanked
    integer :: count,i
    integer, dimension(1:count) :: values
    ! 
    forall(i=1:count) values(i)=   goi_GWBanked_AF(i)
end subroutine
! --------------------------------------------------
!
! ==============
! C# interface =  public int[] ReclaimedWaterCreated
!
subroutine getReclaimedWaterTotal(count, values)
   use lms_CitiWaterBudgets
    implicit none
    dll_export :: getReclaimedWaterTotal
    integer :: count,i
    integer, dimension(1:count) :: values
    ! 
    forall(i=1:count) values(i)=   goi_ReclaimedWtotal_AF(i)
end subroutine
! --------------------------------------------------
!


subroutine getReclaimedWaterOut(count, values)
   use lms_CitiWaterBudgets
    implicit none
    dll_export :: getReclaimedWaterOut
    integer :: count,i
    integer, dimension(1:count) :: values
    ! 
    forall(i=1:count) values(i)=   goi_ReclaimedWoutput_AF(i)
end subroutine
! --------------------------------------------------
!
! ==============
! C# interface =   public int[] ReclaimedWaterUsed
!
subroutine getReclaimedWaterUsed(count, values)
   use lms_CitiWaterBudgets
    implicit none
    dll_export :: getReclaimedWaterUsed
    integer :: count,i
    integer, dimension(1:count) :: values
    ! 
    forall(i=1:count) values(i)=   goi_ReclaimedWused_AF(i)
end subroutine
! --------------------------------------------------
!
! ==============
! C# interface =   public int[] ReclaimedWaterUsed
!
subroutine getReclaimedDifference(count, values)
   use lms_CitiWaterBudgets
    implicit none
    dll_export :: getReclaimedDifference
    integer :: count,i
    integer, dimension(1:count) :: values
    ! 
    forall(i=1:count) values(i)=   goi_ReclaimedDifference_AF(i)
end subroutine
! --------------------------------------------------
!

! ==============
! C# interface =  public int[] ReclaimedWaterToVadose
!
subroutine getReclaimedWaterToVadose(count, values)
   use lms_CitiWaterBudgets
    implicit none
    dll_export :: getReclaimedWaterToVadose
    integer :: count,i
    integer, dimension(1:count) :: values
    ! 
    forall(i=1:count) values(i)=   goi_ReclaimedWrecharged_AF(i)
end subroutine
! --------------------------------------------------
!
! ==============
! C# interface =   public int[] ReclaimedWaterDischarged
!
subroutine getReclaimedWaterDischarged(count, values)
   use lms_CitiWaterBudgets
    implicit none
    dll_export :: getReclaimedWaterDischarged
    integer :: count,i
    integer, dimension(1:count) :: values
    ! 
    forall(i=1:count) values(i)=   goi_ReclaimedWdischarged_AF(i)
end subroutine
! --------------------------------------------------
!
! ==============
! C# interface =  public int[] ReclaimedWaterDirectInject
!
subroutine getReclaimedWaterDInject(count, values)
   use lms_CitiWaterBudgets
    implicit none
    dll_export :: getReclaimedWaterDInject
    integer :: count,i
    integer, dimension(1:count) :: values
    ! 
    forall(i=1:count) values(i)=    goi_ReclaimedWDI_AF(i)
end subroutine
! --------------------------------------------------

! ==============
! C# interface =   public int[] ROreclaimedWaterCreated  
!
subroutine getROReclaimedWaterOut(count, values)
   use lms_CitiWaterBudgets
    implicit none
    dll_export :: getROReclaimedWaterOut
    integer :: count,i
    integer, dimension(1:count) :: values
    ! 
    forall(i=1:count) values(i)=   goi_ROReclaimedWoutput_AF(i)
end subroutine
! --------------------------------------------------
!
! ==============
! C# interface =  public int[] ROreclaimedWaterUsed  
!
subroutine getROReclaimedWaterUsed(count, values)
   use lms_CitiWaterBudgets
    implicit none
    dll_export :: getROReclaimedWaterUsed
    integer :: count,i
    integer, dimension(1:count) :: values
    ! 
    forall(i=1:count) values(i)=   goi_ROReclaimedWused_AF(i)
end subroutine
! --------------------------------------------------
!
! ==============
! C# interface =    public int[] ROreclaimedWaterDirectInject
!
subroutine getROReclaimedWaterDI(count, values)
   use lms_CitiWaterBudgets
    implicit none
    dll_export :: getROReclaimedWaterDI
    integer :: count,i
    integer, dimension(1:count) :: values
    ! 
    forall(i=1:count) values(i)=    goi_ROReclaimedWDI_AF(i)
end subroutine
! --------------------------------------------------
!
! ==============
! C# interface =   public int[] EffluentCreated 
!
subroutine getEffluentCreated(count, values)
   use lms_CitiWaterBudgets
    implicit none
    dll_export :: getEffluentCreated
    integer :: count,i
    integer, dimension(1:count) :: values
    ! 
    forall(i=1:count) values(i)=     goi_Effluent_AF(i)
end subroutine
! --------------------------------------------------
!
! ==============
! C# interface =   public int[] ProviderEffluentToPowerPlant 
!
subroutine getEffluentToPowerPlant(count, values)
   use lms_CitiWaterBudgets
    implicit none
    dll_export ::  getEffluentToPowerPlant
    integer :: count,i
    integer, dimension(1:count) :: values
    ! 
    forall(i=1:count) values(i)=    goi_EffluentPPlant_AF(i)
end subroutine
! --------------------------------------------------
!
! ==============
! C# interface =  public int[] EffluentToVadose 
!
subroutine getEffluentToVadose(count, values)
   use lms_CitiWaterBudgets
    implicit none
    dll_export ::  getEffluentToVadose
    integer :: count,i
    integer, dimension(1:count) :: values
    ! 
    forall(i=1:count) values(i)=    goi_EffluentVadose_AF(i)
end subroutine
! --------------------------------------------------
!
!
! ==============
! C# interface =   public int[] EffluentDischarged
!
subroutine getEffluentToDischarge(count, values)
   use lms_CitiWaterBudgets
    implicit none
    dll_export ::  getEffluentToDischarge
    integer :: count,i
    integer, dimension(1:count) :: values
    ! 
    forall(i=1:count) values(i)=    goi_EffluentToDischarge_AF(i)
end subroutine
! --------------------------------------------------
!
! ==============
! C# interface =  public int EffluentToAgriculture
!
function getEffluentToAg() result(value)
    use lms_CitiWaterBudgets
    implicit none
    dll_export :: getEffluentToAg
    integer :: value

    value = goi_EffluentAg_AF
end function
! --------------------------------------------------

!
! ==============
! C# interface =   internal int[] VadoseToAquiferFlux 
!
subroutine getfluxVadoseToAquifer(count, values)
   use lms_CitiWaterBudgets
    implicit none
    dll_export ::  getfluxVadoseToAquifer
    integer :: count,i
    integer, dimension(1:count) :: values
    ! 
    forall(i=1:count) values(i)=   goi_fluxVadoseToAquifer(i)
end subroutine
! --------------------------------------------------

! --------------------------------------------------
!
! ==============
! C# interface =  public int[] ProviderDemandDeficit
!
subroutine getDemandDeficit(count,values)
   use lms_CitiWaterBudgets
    implicit none
    dll_export ::  getDemandDeficit
    integer :: count
    integer :: i
    integer, dimension(1:count) :: values
    !
    forall(i=1:count) values(i)=    goi_DemandDeficit_AF(i)
end subroutine
! --------------------------------------------------
!
! ==============
! C# interface = internal int FlowToEnvironment_CO
!
subroutine setWaterToEvironmentCO(value)
    use  lms_River_Ba
    implicit none
    dll_export :: setWaterToEvironmentCO
    integer :: value
    !
    gvi_WaterToEnvironCO_AF_a = value

  return
end subroutine
! --------------------------------------------------
!
!
! ==============
! C# interface = internal int FlowToEnvironment_Verde
!
subroutine setWaterToEvironmentVerde(value)
    use  lms_River_Aa
    implicit none
    dll_export :: setWaterToEvironmentVerde
    integer :: value
    !
    gvi_WaterToEnvironVerde_AF_a = value

  return
end subroutine
! --------------------------------------------------

!
! ==============
! C# interface = internal int FlowToEnvironment_Salt
!
subroutine setWaterToEvironmentSalt(value)
    use  lms_River_Aa
    implicit none
    dll_export :: setWaterToEvironmentSalt
    integer :: value
    !
    gvi_WaterToEnvironSalt_AF_a = value

  return
end subroutine
! --------------------------------------------------
!
! ==============
! C# interface = internal int [] WaterFromAgPumping
!
subroutine getWaterFromAgPumping(count, values)
   use lm_ParameterControl
    implicit none
    dll_export ::  getWaterFromAgPumping
    integer :: count,i
    integer, dimension(1:count) :: values
    ! 
    forall(i=1:count) values(i)= gvi_WaterFromAgPumping_AF_a(i)
end subroutine
! --------------------------------------------------
! ==============
! C# interface = internal int [] WaterFromAgPumping
!
subroutine setWaterFromAgPumping(count, values)
   use lm_ParameterControl 
    implicit none
    dll_export ::  setWaterFromAgPumping
    integer :: count,i
    integer, dimension(1:count) :: values
    real, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=0.0
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i)
    end forall
    
    forall(i=1:count) gvi_WaterFromAgPumping_AF_a(i)=nint(generic(i))
end subroutine
! --------------------------------------------------
!
! ==============
! C# interface = internal int [] WaterFromAgPumping
!
subroutine getWaterFromAgSurface(count, values)
   use  lms_River_Ba
    implicit none
    dll_export ::  getWaterFromAgSurface
    integer :: count,i
    integer, dimension(1:count) :: values
    ! 
    forall(i=1:count) values(i)= gvi_WaterFromAgSurface_AF_a(i)
end subroutine
! --------------------------------------------------
! ==============
! C# interface = internal int [] WaterFromAgSurface
!
subroutine setWaterFromAgSurface(count, values)
   use  lms_River_Ba
    implicit none
    dll_export ::  setWaterFromAgSurface
    integer :: count,i
    integer, dimension(1:count) :: values
    real, dimension(1:count) :: generic
    !
    forall(i=1:count)generic(i)=0.0
    forall(i=1:count, values(i) .gt. -1)
      generic(i) = values(i)
    end forall

    forall(i=1:count) gvi_WaterFromAgSurface_AF_a(i)=generic(i)
end subroutine
! --------------------------------------------------

! --------------------------------------------------
!
! ==============
! C# interface = 
!
! --------------------------------------------------
! Generic subroutines
! ===========================
!subroutine set(count, values)
!    use lm_ParameterControl
!    implicit none
!    dll_export :: set
!    integer :: count,i
!    integer, dimension(1:count) :: values
!    !
!    forall(i=1:count) gvf_(i)= values(i)
!end subroutine
!!
!function get() result(value)
!    use lms_CitiWaterBudgets
!    implicit none
!    dll_export :: get
!    integer :: value
!
!    value = goi__AF
!end function

! End of functions and subroutines
! =================================================================================================
! E.O.F.