!
! File is TDS_CityModel.f90
!
! This file controls the salinity modeling of the City Model
!
!
! Global OUTPUTS:
!                             
!
! Local OUTPUTS:
!               
!   
! Local INPUTS:
!                  
!              
!
! Created on: 06.22.10
!
! last write was: 02.10.12
! ------------------------
!
! =================================================================================================
Module lm_TDScityModel
 use gm_ModelControl
   use gm_GlobalData

    implicit none
    !
!    include 'D:\WaterSim\WaterSimTesting\WaterSimTesting\bin\Debug\App_Data\WaterSim_4_0\App_Data\Include\UGuildTest.inc'
    !
    contains
      !
      subroutine initTDS()
!       call openFiles_T()
!       call readFiles_T()
!       call initialState_T()
      end subroutine initTDS
      ! --------------------
End Module lm_TDScityModel
!
Module lms_TDScityModel
 use gm_ModelControl
   use gm_GlobalData
    use gm_TypeControl
    
    implicit none
   ! --------------
      !
      ! Constants (or global variables to change)
      ! --------------
      real, private :: cv_galToLiter=3.785411784
      real, private :: cv_mgToMg=0.000000001
      real, private :: cv_galToAF=325853.32069
      real, private :: cv_acftTomaf=1000000
      real, private :: cv_metricTonsToGg=0.001
      !
      logical, private :: gvl_startup
      !
      real, private :: cv_mglToMgAF
      !
      real, public  :: gvf_TDSverdeRiver_mgl=310
      real, public  :: gvf_TDSsaltRiver_mgl=1100
      real, public  :: gvf_verdeProportion=0.43
      real, public  :: gvf_TDScapwater_mgl=600
      !
      real, public  :: gvf_TDSreclaimed_mgl=1100
      real, public  :: gvf_TDSROreclaimed_mgl=400

      !
      real, public :: gvf_TDSAg_mgl=650
      real, public :: gvf_TDSmunicipalGW_mgl=600
      real, public :: gvf_TDSmunicipalGWtreated_mgl=500

      real, public :: gvf_TDSsrpGW_mgl=600
      real, public :: gvf_TDSrecharge_mgl=690
      real, public :: gvf_TDSinitialGW_mgl(gvi_maxProV)=1000
      real, public :: gvf_TDScio_mgl=800
      real, public :: gvf_TDSaddToMuniWW_mgl=400

      real, public :: gvf_TDSaddToIndWW_mgl=400

      real, public :: gvf_TDSres_mgl=800
      real, public :: gvf_TDSresWW_mgl=1000
      real, public :: gvf_TDScioWW_mgl=1000

      real, public :: gvf_ROremovelRate=0.95
      real, public :: gvf_ROprocessIrrig=0.10
      real, public :: gvf_AWWTPtoRO=0.9     ! THIS needs parameterization

      !
      ! ---------------------------------------------------------------
      !
      ! Fluxes
      ! --------------
      real, private :: lvf_fluxCAPWater_MgMonth(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_fluxSRPsurfWater_MgMonth(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_fluxGWBanking_MgMonth(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_fluxGW_SRP_MgMonth(gvi_maxProV, gpi_timeStepWB)

      !
       real, private :: lvf_fluxSWtoVadose_MgMonth(gvi_maxProV, gpi_timeStepWB)
        real, private :: lvf_fluxSWtoSWTP_MgMonth(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_fluxSWTPtoWS_MgMonth(gvi_maxProV, gpi_timeStepWB)
      !
      real, private :: lvf_fluxWStoRes_MgMonth(gvi_maxProV, gpi_timeStepWB)
       real, private :: lvf_fluxResToIndoor_MgMonth(gvi_maxProV, gpi_timeStepWB)
        real, private :: lvf_fluxResToOutdoor_MgMonth(gvi_maxProV, gpi_timeStepWB)
         real, private :: lvf_fluxResWW_MgMonth(gvi_maxProV, gpi_timeStepWB)
          real, private :: lvf_fluxResIndoorAdded_MgMonth(gvi_maxProV, gpi_timeStepWB)
      !
      real, private :: lvf_fluxWStoCio_MgMonth(gvi_maxProV, gpi_timeStepWB)
       real, private :: lvf_fluxCioToIndoor_MgMonth(gvi_maxProV, gpi_timeStepWB)
        real, private :: lvf_fluxCioToOutdoor_MgMonth(gvi_maxProV, gpi_timeStepWB)
         real, private :: lvf_fluxCioWW_MgMonth(gvi_maxProV, gpi_timeStepWB)
          real, private :: lvf_fluxCioIndoorAdded_MgMonth(gvi_maxProV, gpi_timeStepWB)

      real, private :: lvf_fluxWWtoRWWTP_MgMonth(gvi_maxProV, gpi_timeStepWB)
       real, private :: lvf_fluxWWtoTWWTP_MgMonth(gvi_maxProV, gpi_timeStepWB)
         real, private :: lvf_fluxEffluentToAg_MgMonth(gvi_maxProV, gpi_timeStepWB)
           real, private :: lvf_fluxEffluentToVadose_MgMonth(gvi_maxProV, gpi_timeStepWB)
             real, private :: lvf_fluxEffluentToPPlant_MgMonth(gvi_maxProV, gpi_timeStepWB)

      !
      real, private :: lvf_fluxTWWTPtoEffluent(gvi_maxProV, gpi_timeStepWB)
        real, private :: lvf_fluxTWWTPtoWWdischarge_MgMonth(gvi_maxProV, gpi_timeStepWB)

      real, private :: lvf_fluxRWWTPtoRO_MgMonth(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_fluxRWWTPtoReclaimed_MgMonth(gvi_maxProV, gpi_timeStepWB)
      !
      real,private :: lvf_reclaimedToVadose_MgMonth(gvi_maxProV, gpi_timeStepWB)
       real,private :: lvf_reclaimedToDinject_MgMonth(gvi_maxProV, gpi_timeStepWB)
        real,private :: lvf_reclaimedToOutput_MgMonth(gvi_maxProV, gpi_timeStepWB)
         real,private :: lvf_reclaimedToWWSurfDisch_MgMonth(gvi_maxProV, gpi_timeStepWB)
          real,private :: lvf_reclaimedToInput_MgMonth(gvi_maxProV, gpi_timeStepWB)
      !
      real, private :: lvf_fluxROToDInject_MgMonth(gvi_maxProV, gpi_timeStepWB)
       real, private :: lvf_fluxROToOutput_MgMonth(gvi_maxProV, gpi_timeStepWB)
        real,private :: lvf_ROreclaimedToInput_MgMonth(gvi_maxProV, gpi_timeStepWB)
      !
      real,private :: lvf_fluxWStoDIinject_MgMonth(gvi_maxProV, gpi_timeStepWB)

      !
      real, private :: lvf_fluxRESoutdoorPerc_MgMonth(gvi_maxProV, gpi_timeStepWB)
       real, private :: lvf_fluxCIOoutdoorPerc_MgMonth(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_fluxRunoffPerc_MgMonth(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_fluxAgPerc_MgMonth(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_fluxGroundwaterToAg_MgMonth(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_fluxNaturalRecharge_MgMonth(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_fluxSaltInMuniGwaterPumped_MgMonth(gvi_maxProV, gpi_timeStepWB)
      !

   

      ! ---------------------------------------------------------------
      !
      ! States
      ! --------------
      real, private :: lvf_stateSurfaceWater(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_stateSWTP(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_stateWS(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_stateCIO(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_stateCIOindoor(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_stateCIOoutdoor(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_stateRES(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_stateRESindoor(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_stateRESoutdoor(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_stateTWWTP(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_stateRWWTP(gvi_maxProV, gpi_timeStepWB)

      real, private :: lvf_stateRO(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_stateReclaimed(gvi_maxProV, gpi_timeStepWB)

      real, private :: lvf_stateROpermeate(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_stateVadose(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_stateAquifer(gvi_maxProV, gpi_timeStepWB)
      real, private :: lvf_stateAgIrrig(gvi_maxProV, gpi_timeStepWB)

      !
      ! --------------------------------------------------------------------------
      ! TDS type variables
      ! -------------------
      type TDSt
        real :: lvf_TDScap_MgAF(gvi_maxProV, gpi_timeStepWB),lvf_TDSsrpClassA_MgAF(gvi_maxProV, gpi_timeStepWB)
        real :: lvf_TDSreclaimed_MgAF(gvi_maxProV, gpi_timeStepWB),lvf_TDSro_reclaimed_MgAF(gvi_maxProV, gpi_timeStepWB)
        real :: lvf_TDSbanking_MgAF(gvi_maxProV, gpi_timeStepWB)
        !
        real :: lvf_TDSAg_MgAF(gvi_maxProV, gpi_timeStepWB)
        real :: lvf_TDSmunicipalGW_MgAF,lvf_TDSsrpGW_MgAF,lvf_TDSinitGW_MgAF(gvi_maxProV, gpi_timeStepWB)
        real :: lvf_TDSmunicipalGWtreated_MgAF
        !
        real :: lvf_TDSrecharge_MgAF(gvi_maxProV, gpi_timeStepWB)
        real :: lvf_TDSsrpSaltRiverClassA_mgl(gvi_maxProV, gpi_timeStepWB)
          !
        real :: lvf_TDSreclaimed_mgl(gvi_maxProV, gpi_timeStepWB)
        real :: lvf_TDSro_reclaimed_mgl(gvi_maxProV, gpi_timeStepWB)
        real :: lvf_TDSbanking_mgl(gvi_maxProV, gpi_timeStepWB)
        real :: lvf_TDSgwtreatment_mgl(gvi_maxProV, gpi_timeStepWB)
          !
        real :: lvf_TDSmixedSurfaceWater_mgl(gvi_maxProV, gpi_timeStepWB)
        real :: lvf_TDSmixedInputMandI_mgl(gvi_maxProV, gpi_timeStepWB)
        real :: lvf_TDSmixedMandIWW_mgl(gvi_maxProV, gpi_timeStepWB)
        real :: lvf_TDSrunoff_mgl(gvi_maxProV, gpi_timeStepWB),lvf_TDSrunoff_MgAF(gvi_maxProV, gpi_timeStepWB)
        real :: lvf_TDSprecip_mgl(gvi_maxProV, gpi_timeStepWB),lvf_TDSprecip_MgAF(gvi_maxProV, gpi_timeStepWB)

        real :: lvf_TDScio_mgl(gvi_maxProV, gpi_timeStepWB),lvf_TDScio_MgAF(gvi_maxProV, gpi_timeStepWB)
        real :: lvf_TDSres_mgl(gvi_maxProV, gpi_timeStepWB),lvf_TDSres_MgAF(gvi_maxProV, gpi_timeStepWB)
        real :: lvf_TDScioWW_mgl(gvi_maxProV, gpi_timeStepWB),lvf_TDScioWW_MgAF(gvi_maxProV, gpi_timeStepWB)
        real :: lvf_TDSresWW_mgl(gvi_maxProV, gpi_timeStepWB),lvf_TDSresWW_MgAF(gvi_maxProV, gpi_timeStepWB)
        real :: lvf_TDSaddToIndustry_mgl(gvi_maxProV, gpi_timeStepWB),lvf_TDSaddToIndustry_MgAF(gvi_maxProV, gpi_timeStepWB)
        real :: lvf_TDSindustrialReuseWW_mgl(gvi_maxProV, gpi_timeStepWB),lvf_TDSWWforIndustrialReuse_mgl(gvi_maxProV, gpi_timeStepWB)
        !
        real :: lvf_TDSregionalWWdischarge_mgl(gvi_maxProV, gpi_timeStepWB)
      end type TDSt
      !
    ! ------------------------------------------------------------------------------------------------------------
    !
    include 'C:\WaterSim\WaterSimTesting\WaterSimTesting\bin\Debug\App_Data\WaterSim_4_0\App_Data\Include\WaterSimDCDC.txt'
    !
 ! ================================================================================================
    contains
      subroutine TDS(T,i,j,lvSB)
        implicit none
        integer :: i,j

         type(SalinityWB)lvSB
         type(TDSt)lvTDS
         type(runTime)T
        ! =====================
          !
           if(gvl_startup)then
              call zMixed(lvTDS)
            endif
         !
          call TDS_surfacewater(i,j,lvTDS)
           call TDS_mixedInputs(i,j,lvTDS,lvSB)
            call TDS_res(i,j,lvTDS)
           call TDS_cio(i,j,lvTDS)
          call TDS_groundwater(i,j,lvTDS)
          !
          call fluxes(T,i,j,lvTDS,lvSB)
          call states(i,j)
          !
        return
      end subroutine TDS
      ! ----------------

        ! ----------------------
        subroutine zMixed(lvTDS)
          integer :: k,l

!          type(SalinityWB)lvSB
          type(TDSt)lvTDS
          ! ==================
            !
            do k = 1,gvi_Providers,1
              do l = 1, gpi_timeStepWB,1
                lvTDS%lvf_TDScioWW_mgl(k,l)=gvf_TDScioWW_mgl
                lvTDS%lvf_TDSresWW_mgl(k,l)=gvf_TDSresWW_mgl
                lvTDS%lvf_TDSindustrialReuseWW_mgl(k,l)=(gvf_TDScioWW_mgl+gvf_TDSresWW_mgl)/2
              end do
            end do
            !    
         return
        end subroutine zMixed
        ! -------------------

        ! ------------------------------------
        subroutine TDS_surfacewater(i,j,lvTDS)
          integer :: i,j

          type(TDSt)lvTDS
          ! =============
            !
            cv_mglToMgAF= cv_galToLiter*cv_mgToMg*cv_galToAF
            !
            lvTDS%lvf_TDScap_MgAF(i,j)=gvf_TDScapwater_mgl *cv_mglToMgAF    
            !
            lvTDS%lvf_TDSsrpSaltRiverClassA_mgl(i,j)=gvf_TDSverdeRiver_mgl*gvf_verdeProportion &
                  +gvf_TDSsaltRiver_mgl*(1-gvf_verdeProportion)
            !
            lvTDS%lvf_TDSsrpClassA_MgAF(i,j)=lvTDS%lvf_TDSsrpSaltRiverClassA_mgl(i,j)*cv_mglToMgAF
            !
              ! Place holder- this needs parameterization or input
             lvTDS%lvf_TDSreclaimed_mgl(i,j)=gvf_TDSreclaimed_mgl
            lvTDS%lvf_TDSreclaimed_MgAF(i,j)=lvTDS%lvf_TDSreclaimed_mgl(i,j)*cv_mglToMgAF

             lvTDS%lvf_TDSro_reclaimed_mgl(i,j)=gvf_TDSROreclaimed_mgl
            lvTDS%lvf_TDSro_reclaimed_MgAF(i,j)=lvTDS%lvf_TDSro_reclaimed_mgl(i,j)*cv_mglToMgAF

            lvTDS%lvf_TDSbanking_MgAF(i,j)= lvTDS%lvf_TDSrecharge_MgAF(i,j)

             lvTDS%lvf_TDSrunoff_mgl(i,j)=600
            lvTDS%lvf_TDSrunoff_MgAF(i,j)=lvTDS%lvf_TDSrunoff_mgl(i,j)*cv_mglToMgAF
            !
             lvTDS%lvf_TDSprecip_mgl(i,j)=10
            lvTDS%lvf_TDSprecip_MgAF(i,j)= lvTDS%lvf_TDSprecip_mgl(i,j)*cv_mglToMgAF
            !
         return
        end subroutine TDS_surfacewater
        ! -----------------------------

        ! ---------------------------------------
        subroutine TDS_mixedInputs(i,j,lvTDS,lvSB)
          integer :: i,j
          real :: lvf_cap,lvf_classA,lvf_NCS,lvf_classBCstorage

          type(SalinityWB)lvSB
          type(TDSt)lvTDS
          ! ==================
            !
             lvf_cap=0
            lvf_cap=lvSB%gvf_sCAPtoTDS_acft(i,j)
             lvf_classA=0
            lvf_classA=lvSB%gvf_sSRPclassAtoTDS_acft(i,j)
             lvf_NCS=0
            lvf_NCS=lvSB%gvf_sSRPNCStoTDS_acft(i,j)
             lvf_classBCstorage=0
            lvf_classBCstorage=lvSB%gvf_sSRPclassBCstorage_acft(i,j)
            !
            if(0 < (lvf_cap+lvf_classA+lvf_NCS+lvf_classBCstorage))then
              lvTDS%lvf_TDSmixedSurfaceWater_mgl(i,j)= (&
                lvTDS%lvf_TDSsrpSaltRiverClassA_mgl(i,j)* lvSB%gvf_sSRPclassAtoTDS_acft(i,j) &
              + gvf_TDScapwater_mgl*lvSB%gvf_sCAPtoTDS_acft(i,j) &
              + lvTDS%lvf_TDSsrpSaltRiverClassA_mgl(i,j)*lvSB%gvf_sSRPNCStoTDS_acft(i,j)     &
              + lvTDS%lvf_TDSsrpSaltRiverClassA_mgl(i,j)*lvSB%gvf_sSRPclassBCstorage_acft(i,j)     &
              +  lvTDS%lvf_TDSsrpSaltRiverClassA_mgl(i,j)*lvSB%gvf_sFluxGWaterBanking(i,j) &
              ) / (lvf_cap+lvf_classA+lvf_NCS+lvf_classBCstorage)
            !
            else
             ! Some providers do not have surface water
             lvTDS%lvf_TDSmixedSurfaceWater_mgl(i,j)=0
            endif

            lvTDS%lvf_TDSinitGW_MgAF(i,j)=gvf_TDSinitialGW_mgl(i)*cv_mglToMgAF
            !
               lvTDS%lvf_TDSmixedInputMandI_mgl(i,j)= 0
              lvTDS%lvf_TDSmixedInputMandI_mgl(i,j)= ( &
                   (gvf_TDSinitialGW_mgl(i)*lvSB%gvf_sMuniPumpingtoTDS_acft(i,j)) &
                +  (gvf_TDSmunicipalGWtreated_mgl*lvSB%gvf_sMuniPumpingTreatedtoTDS_acft(i,j)) &
                +  (lvTDS%lvf_TDSmixedSurfaceWater_mgl(i,j)*lvSB%gvf_sFluxSWTPtoWS_SW_acft(i,j))    &
                +  (lvTDS%lvf_TDSreclaimed_mgl(i,j) * lvSB%gvf_sReclaimed_acft(i,j))                        &
                +  (lvTDS%lvf_TDSro_reclaimed_mgl(i,j)* lvSB%gvf_sROreclaimed_acft(i,j))                   &
                ) /(lvSB%gvf_sMuniPumpingtoTDS_acft(i,j)+lvSB%gvf_sMuniPumpingTreatedtoTDS_acft(i,j) &
                    + lvSB%gvf_sFluxSWTPtoWS_SW_acft(i,j)+ lvSB%gvf_sReclaimed_acft(i,j) &
                    + lvSB%gvf_sROreclaimed_acft(i,j))

if(i == 33)then
endif
              lvTDS%lvf_TDSaddToIndustry_mgl(i,j)=gvf_TDSaddToIndWW_mgl
          
            lvTDS%lvf_TDSaddToIndustry_MgAF(i,j)=lvTDS%lvf_TDSaddToIndustry_mgl(i,j)*cv_mglToMgAF
            !
             lvTDS%lvf_TDSWWforIndustrialReuse_mgl(i,j)=0
            !   
            lvTDS%lvf_TDSindustrialReuseWW_mgl(i,j)=lvTDS%lvf_TDSWWforIndustrialReuse_mgl(i,j) &
              +  lvTDS%lvf_TDSaddToIndustry_mgl(i,j)
            !
            if(0 < lvSB%gvf_sFluxWWcioToWWTP_acft(i,j)+lvSB%gvf_sFluxWWresToWWTP_acft(i,j))then
               lvTDS%lvf_TDSmixedMandIWW_mgl(i,j)= (&
               lvTDS%lvf_TDScioWW_mgl(i,j)*lvSB%gvf_sFluxWWcioToWWTP_acft(i,j) &
              +lvTDS%lvf_TDSindustrialReuseWW_mgl(i,j)*0 &
              +lvTDS%lvf_TDSresWW_mgl(i,j)*lvSB%gvf_sFluxWWresToWWTP_acft(i,j) &
              ) /(lvSB%gvf_sFluxWWcioToWWTP_acft(i,j)+ 0 &
              + lvSB%gvf_sFluxWWresToWWTP_acft(i,j))
           else
            lvTDS%lvf_TDSmixedMandIWW_mgl(i,j)=0
           endif
            !
          return
        end subroutine TDS_mixedInputs 
        ! ----------------------------

        ! ----------------------------------
        subroutine TDS_groundwater(i,j,lvTDS)
          integer :: i,j

          type(TDSt)lvTDS
          ! ==================
            !
              lvTDS%lvf_TDSAg_MgAF(i,j)=0
              
             if(gvf_TDSAg_mgl == 650)then
              lvTDS%lvf_TDSAg_MgAF(i,j)= lvTDS%lvf_TDSmixedSurfaceWater_mgl(i,j)*cv_mglToMgAF
             else
              lvTDS%lvf_TDSAg_MgAF(i,j)= gvf_TDSAg_mgl*cv_mglToMgAF
             endif
              !
              lvTDS%lvf_TDSrecharge_MgAF(i,j)=0
             if(gvf_TDSrecharge_mgl == 690)then
              lvTDS%lvf_TDSrecharge_MgAF(i,j)= lvTDS%lvf_TDSmixedSurfaceWater_mgl(i,j)*cv_mglToMgAF
             else
              lvTDS%lvf_TDSrecharge_MgAF(i,j)=gvf_TDSrecharge_mgl*cv_mglToMgAF
             endif 
            !
            lvTDS%lvf_TDSmunicipalGW_MgAF=(gvf_TDSmunicipalGW_mgl*cv_mglToMgAF) 
            lvTDS%lvf_TDSmunicipalGWtreated_MgAF=(gvf_TDSmunicipalGWtreated_mgl*cv_mglToMgAF) 

            lvTDS%lvf_TDSsrpGW_MgAF=gvf_TDSsrpGW_mgl*cv_mglToMgAF                                
          return
        end subroutine TDS_groundwater
        ! ----------------------------

        ! ---------------------------
        subroutine TDS_res(i,j,lvTDS)
          integer :: i,j

          type(TDSt)lvTDS
          ! ==================
            !
            if(gvf_TDSres_mgl == 800)then
              lvTDS%lvf_TDSres_mgl(i,j)=lvTDS%lvf_TDSmixedInputMandI_mgl(i,j)
            else
              lvTDS%lvf_TDSres_mgl(i,j)=gvf_TDSres_mgl
            endif            
            lvTDS%lvf_TDSres_MgAF(i,j)=lvTDS%lvf_TDSres_mgl(i,j)*cv_mglToMgAF
            !
if(i == 33)then
endif

            if(gvf_TDSresWW_mgl == 1000)then
              lvTDS%lvf_TDSresWW_mgl(i,j)=lvTDS%lvf_TDSres_mgl(i,j)+gvf_TDSaddToMuniWW_mgl 
            else
              lvTDS%lvf_TDSresWW_mgl(i,j)=gvf_TDSresWW_mgl
            endif            
            lvTDS%lvf_TDSresWW_MgAF(i,j)=lvTDS%lvf_TDSresWW_mgl(i,j)*cv_mglToMgAF
           return
        end subroutine TDS_res
        ! --------------------

        ! ---------------------------
        subroutine TDS_cio(i,j,lvTDS)
          integer :: i,j

          type(TDSt)lvTDS
          ! ==================
            !
            if(gvf_TDScio_mgl == 800)then
              lvTDS%lvf_TDScio_mgl(i,j)=lvTDS%lvf_TDSmixedInputMandI_mgl(i,j)
            else
              lvTDS%lvf_TDScio_mgl(i,j)=gvf_TDScio_mgl
            endif            
            lvTDS%lvf_TDScio_MgAF(i,j)=lvTDS%lvf_TDScio_mgl(i,j)*cv_mglToMgAF
            !
           if(gvf_TDScioWW_mgl == 1000)then
              lvTDS%lvf_TDScioWW_mgl(i,j)=lvTDS%lvf_TDScio_mgl(i,j)+gvf_TDSaddToMuniWW_mgl 
            else
              lvTDS%lvf_TDScioWW_mgl(i,j)=gvf_TDScioWW_mgl
            endif            
            lvTDS%lvf_TDScioWW_MgAF(i,j)=lvTDS%lvf_TDScioWW_mgl(i,j)*cv_mglToMgAF
           return
        end subroutine TDS_cio
        ! --------------------

         ! ----------------------------------
          subroutine fluxes(T,i,j,lvTDS,lvSB)
            integer :: i,j,k,l

            real :: lv_fracRWWTP(gvi_maxProV, gpi_timeStepWB)
            real :: lv_fracTWWTP(gvi_maxProV, gpi_timeStepWB)
            real :: lvf_fracEffluentToAg(gvi_maxProV, gpi_timeStepWB)
            real :: lvf_fracEffluentToVadose(gvi_maxProV, gpi_timeStepWB),lvf_fracEffluentToPP(gvi_maxProV, gpi_timeStepWB)
 
            real :: lv_addWWsurfaces(gvi_maxProV, gpi_timeStepWB)
            real :: lvf_WasteWater
            real :: lvf_Effluent_MgTstep(gvi_maxProV, gpi_timeStepWB)

            type(SalinityWB)lvSB
            type(TDSt)lvTDS
            type(runTime)T
            ! =====================
                !
                if(gvl_startup)then
                  do k = 1,gvi_Providers,1
                    do l = 1, gpi_timeStepWB,1
                       lv_fracRWWTP(k,l)=0
                        lvf_fracEffluentToAg(k,l)=0
                      lv_addWWsurfaces(k,l)=0
                    end do
                  end do
                else             
                 lvf_fluxSWtoSWTP_MgMonth(i,j)=0;lv_fracRWWTP(i,j)=0  
                  lvf_fracEffluentToAg(i,j)=0;lv_addWWsurfaces(i,j)=0
                endif
                !
            ! ==================
            !
            ! surface water
            ! ---------------------------
            lvf_fluxCAPWater_MgMonth(i,j)= lvTDS%lvf_TDScap_MgAF(i,j)*lvSB%gvf_sCAPtoTDS_acft(i,j)
            lvf_fluxSRPsurfWater_MgMonth(i,j)= &
              lvTDS%lvf_TDSsrpClassA_MgAF(i,j)*lvSB%gvf_sSRPclassAtoTDS_acft(i,j) &
               + lvTDS%lvf_TDSsrpClassA_MgAF(i,j)*lvSB%gvf_sSRPclassBCstorage_acft(i,j)


 !lvf_reclaimedToInput_MgMonth(i,j)
            ! SRP Groundwater- place holder
             lvf_fluxGW_SRP_MgMonth(i,j)=0
            lvf_fluxGW_SRP_MgMonth(i,j)= lvTDS%lvf_TDSsrpGW_MgAF *lvSB%gvf_sSRPclassBCtoTDS_acft(i,j)

            ! Municipal Groundwater
            lvf_fluxSaltInMuniGwaterPumped_MgMonth(i,j)= lvTDS%lvf_TDSmunicipalGW_MgAF*lvSB%gvf_sMuniPumpingtoTDS_acft(i,j) &
              + lvSB%gvf_sMuniPumpingTreatedtoTDS_acft(i,j)*0.6

            ! From groundwater banking
            lvf_fluxGWBanking_MgMonth(i,j)= lvTDS%lvf_TDSmunicipalGW_MgAF*lvSB%gvf_sFluxGWaterBanking(i,j)  
            !
            ! As of version 5.0 this becomes TDS to groundwater banking -08.03.11
            lvf_fluxSWtoVadose_MgMonth(i,j)= &
              lvTDS%lvf_TDSrecharge_MgAF(i,j)*lvSB%gvf_sMuniRechargeToTDS_acft(i,j)
              !
            lvf_fluxSWtoSWTP_MgMonth(i,j)= &
              (lvf_fluxCAPWater_MgMonth(i,j)+lvf_fluxSRPsurfWater_MgMonth(i,j)+ lvf_fluxGWBanking_MgMonth(i,j))

            ! Presently, I assume no water lost at the SWTP so, no change in concentration
            lvf_fluxSWTPtoWS_MgMonth(i,j)=lvf_fluxSWtoSWTP_MgMonth(i,j)
            !
            !
            ! Residential
            ! --------------------------
            ! Water supply includes all water- potable and non-potable
            lvf_fluxWStoRes_MgMonth(i,j)=lvTDS%lvf_TDSres_MgAF(i,j)* lvSB%gvf_sFluxRes_acft(i,j)

              lvf_fluxResToIndoor_MgMonth(i,j)= &
                  lvTDS%lvf_TDSres_MgAF(i,j)*lvSB%gvf_sFluxResIndoor_acft(i,j)

                lvf_fluxResToOutdoor_MgMonth(i,j)= &
                    lvTDS%lvf_TDSres_MgAF(i,j)*lvSB%gvf_sFluxResOutdoor_acft(i,j)

                  lvf_fluxResWW_MgMonth(i,j)= &
                      lvTDS%lvf_TDSresWW_MgAF(i,j)*lvSB%gvf_sFluxWWresToWWTP_acft(i,j)

                    lvf_fluxResIndoorAdded_MgMonth(i,j)= &
                      lvf_fluxResWW_MgMonth(i,j)-lvf_fluxResToIndoor_MgMonth(i,j)
            !
            ! Commercial,Industrial,Other
            ! ---------------------------
            lvf_fluxWStoCio_MgMonth(i,j)=lvTDS%lvf_TDScio_MgAF(i,j)*lvSB%gvf_sFluxCio_acft(i,j)
              lvf_fluxCioToIndoor_MgMonth(i,j)= &
                  lvTDS%lvf_TDScio_MgAF(i,j)*lvSB%gvf_sFluxCioIndoor_acft(i,j)
                lvf_fluxCioToOutdoor_MgMonth(i,j)= &
                    lvTDS%lvf_TDScio_MgAF(i,j)*lvSB%gvf_sFluxCioOutdoor_acft(i,j)
                  lvf_fluxCioWW_MgMonth(i,j)= &
                      lvTDS%lvf_TDScioWW_MgAF(i,j)*lvSB%gvf_sFluxWWcioToWWTP_acft(i,j)
                    lvf_fluxCioIndoorAdded_MgMonth(i,j)= &
                      lvf_fluxCioWW_MgMonth(i,j)-lvf_fluxCioToIndoor_MgMonth(i,j)
             !
            ! WW fractions 
            ! -----------------------
              !
                lvf_WasteWater=0
              lvf_WasteWater=lvSB%gvf_sFluxWWresToWWTP_acft(i,j)+lvSB%gvf_sFluxWWcioToWWTP_acft(i,j)
              if( 0 < lvf_WasteWater)then
              lv_fracTWWTP(i,j)=(lvf_WasteWater-lvSB%gvf_sFluxWWwwtpToRWWTP_acft(i,j)) / lvf_WasteWater
              lv_fracRWWTP(i,j)=(lvf_WasteWater- lv_fracTWWTP(i,j)) / lvf_WasteWater
              endif
              !

              ! 08.23.11
              !  Effluent 
              ! ------------------------------------------------------------------------
              ! If gvf_parm_WWtoEffluent .not. 100%, some could go to Surfaces discharge
              ! 
              lvf_fluxWWtoTWWTP_MgMonth(i,j)= lv_fracTWWTP(i,j) &
                * (lvf_fluxResWW_MgMonth(i,j)+ lvf_fluxCioWW_MgMonth(i,j))

               lvf_Effluent_MgTstep(i,j)=0
              lvf_Effluent_MgTstep(i,j)= lvf_fluxWWtoTWWTP_MgMonth(i,j) * gvf_parm_WWtoEffluent(i)

              lvf_fluxTWWTPtoEffluent(i,j)=  lvf_Effluent_MgTstep(i,j)

               lvf_fracEffluentToPP(i,j)=0
              lvf_fracEffluentToPP(i,j)=(lvf_Effluent_MgTstep(i,j)*gvf_parm_EffluentToPP(i))/lvf_Effluent_MgTstep(i,j)

               lvf_fracEffluentToVadose(i,j)=0
              lvf_fracEffluentToVadose(i,j)=(lvf_Effluent_MgTstep(i,j)*gvf_parm_EffluentToVadose(i))/ lvf_Effluent_MgTstep(i,j)

               lvf_fracEffluentToAg(i,j)=0
              lvf_fracEffluentToAg(i,j)=max(0,1- lvf_fracEffluentToPP(i,j)-lvf_fracEffluentToVadose(i,j))

              lv_addWWsurfaces(i,j)=lvf_fluxWWtoTWWTP_MgMonth(i,j)- lvf_Effluent_MgTstep(i,j)
              ! ----------
              ! TDS fluxes
              lvf_fluxTWWTPtoWWdischarge_MgMonth(i,j)= lv_addWWsurfaces(i,j)

              lvf_fluxEffluentToAg_MgMonth(i,j)= lvf_fracEffluentToAg(i,j)*lvf_Effluent_MgTstep(i,j)

              lvf_fluxEffluentToVadose_MgMonth(i,j)= lvf_Effluent_MgTstep(i,j)*lvf_fracEffluentToVadose(i,j)

              lvf_fluxEffluentToPPlant_MgMonth(i,j)=lvf_Effluent_MgTstep(i,j)* gvf_parm_EffluentToPP(i)
            !
            ! ====================================================================================

            !  Reclaimed
            ! -----------------------
              !
            lvf_fluxWWtoRWWTP_MgMonth(i,j)= lv_fracRWWTP(i,j) &
              * (lvf_fluxResWW_MgMonth(i,j)+ lvf_fluxCioWW_MgMonth(i,j))
  
            ! These are new: 

              ! Reclaimed
             lvf_fluxRWWTPtoReclaimed_MgMonth(i,j)=0
            lvf_fluxRWWTPtoReclaimed_MgMonth(i,j)=lvf_fluxWWtoRWWTP_MgMonth(i,j) * (1-gvf_parm_RWWtoRO(i))

              lvf_reclaimedToOutput_MgMonth(i,j)=0
             lvf_reclaimedToOutput_MgMonth(i,j)=lvf_fluxRWWTPtoReclaimed_MgMonth(i,j)* gvf_parm_RtoOutput(i)

              lvf_reclaimedToDinject_MgMonth(i,j)=0
             lvf_reclaimedToDinject_MgMonth(i,j)=lvf_fluxRWWTPtoReclaimed_MgMonth(i,j)* gvf_parm_RtoDInjection(i)

              lvf_reclaimedToVadose_MgMonth(i,j)=0
             lvf_reclaimedToVadose_MgMonth(i,j)=lvf_fluxRWWTPtoReclaimed_MgMonth(i,j)*  gvf_parm_RtoVadose(i)

             lvf_reclaimedToWWSurfDisch_MgMonth(i,j)=0
            lvf_reclaimedToWWSurfDisch_MgMonth(i,j)= lvf_fluxRWWTPtoReclaimed_MgMonth(i,j)-( lvf_reclaimedToOutput_MgMonth(i,j) &
              +  lvf_reclaimedToDinject_MgMonth(i,j) + lvf_reclaimedToVadose_MgMonth(i,j))

            lvf_reclaimedToInput_MgMonth(i,j)= lvf_reclaimedToOutput_MgMonth(i,j) * gvf_parm_RtoInputMaxPct(i)


              ! RO Reclaimed
             lvf_fluxRWWTPtoRO_MgMonth(i,j)=0
            lvf_fluxRWWTPtoRO_MgMonth(i,j)=lvf_fluxWWtoRWWTP_MgMonth(i,j)*gvf_parm_RWWtoRO(i)

             lvf_fluxROToDInject_MgMonth(i,j)=0
            lvf_fluxROToDInject_MgMonth(i,j)= lvf_fluxRWWTPtoRO_MgMonth(i,j)*(1-gvf_parm_ROtoOutput(i))

             lvf_fluxROToOutput_MgMonth(i,j)=0
            lvf_fluxROToOutput_MgMonth(i,j)=lvf_fluxRWWTPtoRO_MgMonth(i,j)- lvf_fluxROToDInject_MgMonth(i,j)

             lvf_ROreclaimedToInput_MgMonth(i,j)=0
            lvf_ROreclaimedToInput_MgMonth(i,j)= lvf_fluxROToOutput_MgMonth(i,j)
            !
            ! ====================================================================================

            ! WaterSupply
 

            ! Regional WW Surface Discharge
            ! -----------------------------
!            lvf_fluxRegionalWWdischarge_MgMonth(i,j)=max(1-lv_addWWsurfaces(i,j),0) &
!              * ( lvf_fluxResWW_MgMonth(i,j)+ lvf_fluxCioWW_MgMonth(i,j) ) 
            !
 
            lvf_fluxRESoutdoorPerc_MgMonth(i,j)=lvf_fluxResToOutdoor_MgMonth(i,j)
            lvf_fluxCIOoutdoorPerc_MgMonth(i,j)=lvf_fluxCioToOutdoor_MgMonth(i,j)

            lvf_fluxRunoffPerc_MgMonth(i,j)= &
              lvTDS%lvf_TDSrunoff_MgAF(i,j)*lvSB%gvf_sFluxRunoffPerc_acft(i,j)

            lvf_fluxAgPerc_MgMonth(i,j)=0

            lvf_fluxGroundwaterToAg_MgMonth(i,j)= &
              lvSB%gvf_sGwaterToAgToTDS_acft(i,j)* lvTDS%lvf_TDSAg_MgAF(i,j)

            lvf_fluxNaturalRecharge_MgMonth(i,j)=lvf_fluxAgPerc_MgMonth(i,j) &
              + lvf_fluxRESoutdoorPerc_MgMonth(i,j)+ lvf_fluxCIOoutdoorPerc_MgMonth(i,j) &
              + lvf_fluxRunoffPerc_MgMonth(i,j) + lvf_fluxROToDInject_MgMonth(i,j) 

            lvf_fluxSaltInMuniGwaterPumped_MgMonth(i,j)= &
              lvTDS%lvf_TDSmunicipalGW_MgAF*lvSB%gvf_sMuniPumpingtoTDS_acft(i,j)
            !
if(i == 33)then
endif
           return
          end subroutine fluxes
          ! --------------------

         ! ---------------------
          subroutine states(i,j)
            integer :: i,j
            real :: fstates
            real :: a1,a2,a3,a4,a5,s1,s2,s3,s4
            real :: standing

!            type(runTime)T
            ! =============
              !
              ! Add common block variables for states-include
                ! =====================
                !
                standing=0;a1=0;a2=0;a3=0;a4=0;a5=0;s1=0;s2=0;s3=0;s4=0
                !
                ! ==================

             !===================================
                  a1=lvf_fluxCAPWater_MgMonth(i,j);a2=lvf_fluxSRPsurfWater_MgMonth(i,j)
                  a3=lvf_fluxGWBanking_MgMonth(i,j)
                  s1=lvf_fluxSWtoSWTP_MgMonth(i,j);s2=lvf_fluxSWtoVadose_MgMonth(i,j)
                  standing=lvf_stateSurfaceWater(i,j)
                  !
             lvf_stateSurfaceWater(i,j)=fstates(standing,a1,a2,a3,a4,a5,s1,s2,s3,s4)
             !=======================

             !===================================
                standing=0;a1=0;a2=0;a3=0;a4=0;a5=0;s1=0;s2=0;s3=0;s4=0

                  a1=lvf_fluxSWtoSWTP_MgMonth(i,j)
                  s1=lvf_fluxSWTPtoWS_MgMonth(i,j) 
                  standing= lvf_stateSWTP(i,j)
                  !
              lvf_stateSWTP(i,j)=fstates(standing,a1,a2,a3,a4,a5,s1,s2,s3,s4)
             !==================

             !===================================
                standing=0;a1=0;a2=0;a3=0;a4=0;a5=0;s1=0;s2=0;s3=0;s4=0

                  a1=lvf_fluxSWTPtoWS_MgMonth(i,j)  ;a2=lvf_fluxSaltInMuniGwaterPumped_MgMonth(i,j)
                  a3=lvf_reclaimedToInput_MgMonth(i,j)
                  a4=lvf_ROreclaimedToInput_MgMonth(i,j)
                  s1=lvf_fluxWStoRes_MgMonth(i,j)   ;s2=lvf_fluxWStoCio_MgMonth(i,j)
                  s3=lvf_fluxSWtoVadose_MgMonth(i,j)
                  standing=lvf_stateWS(i,j)
                  !
              lvf_stateWS(i,j)=fstates(standing,a1,a2,a3,a4,a5,s1,s2,s3,s4)
             !==================

             !===================================
                standing=0;a1=0;a2=0;a3=0;a4=0;a5=0;s1=0;s2=0;s3=0;s4=0

                  a1=lvf_fluxWStoRes_MgMonth(i,j)
                  s1=lvf_fluxResToIndoor_MgMonth(i,j) ;s2=lvf_fluxResToOutdoor_MgMonth(i,j)
                  standing= lvf_stateRES(i,j)
                  !
              lvf_stateRES(i,j)=fstates(standing,a1,a2,a3,a4,a5,s1,s2,s3,s4)
             !=================
                !===================================
                standing=0;a1=0;a2=0;a3=0;a4=0;a5=0;s1=0;s2=0;s3=0;s4=0

                      a1=lvf_fluxResToIndoor_MgMonth(i,j) ;a2= lvf_fluxResIndoorAdded_MgMonth(i,j)
                      s1=lvf_fluxResWW_MgMonth(i,j)
                      standing= lvf_stateRESindoor(i,j)
                      !
                 lvf_stateRESindoor(i,j)=fstates(standing,a1,a2,a3,a4,a5,s1,s2,s3,s4)
                !==================
                !===================================
                standing=0;a1=0;a2=0;a3=0;a4=0;a5=0;s1=0;s2=0;s3=0;s4=0

                      a1=lvf_fluxResToOutdoor_MgMonth(i,j)
                      s1=lvf_fluxRESoutdoorPerc_MgMonth(i,j)
                      standing= lvf_stateRESOutdoor(i,j)
                     !
                 lvf_stateRESOutdoor(i,j)=fstates(standing,a1,a2,a3,a4,a5,s1,s2,s3,s4)
                !==================

             !===================================
                standing=0;a1=0;a2=0;a3=0;a4=0;a5=0;s1=0;s2=0;s3=0;s4=0

                  a1=lvf_fluxWStoCio_MgMonth(i,j)
                  s1=lvf_fluxCioToIndoor_MgMonth(i,j) ;s2=lvf_fluxCioToOutdoor_MgMonth(i,j)
                  standing= lvf_stateCIO(i,j)
                  !
              lvf_stateCIO(i,j)=fstates(standing,a1,a2,a3,a4,a5,s1,s2,s3,s4)
             !==================
                !===================================
                standing=0;a1=0;a2=0;a3=0;a4=0;a5=0;s1=0;s2=0;s3=0;s4=0

                      a1=lvf_fluxCioToIndoor_MgMonth(i,j) ;a2= lvf_fluxCioIndoorAdded_MgMonth(i,j)
                      s1=lvf_fluxCioWW_MgMonth(i,j)
                      standing= lvf_stateCIOindoor(i,j)
                      !
                 lvf_stateCIOindoor(i,j)=fstates(standing,a1,a2,a3,a4,a5,s1,s2,s3,s4)
                !==================
                !===================================
                standing=0;a1=0;a2=0;a3=0;a4=0;a5=0;s1=0;s2=0;s3=0;s4=0

                      a1=lvf_fluxCioToOutdoor_MgMonth(i,j)
                      s1=lvf_fluxCIOoutdoorPerc_MgMonth(i,j)
                      standing= lvf_stateCIOoutdoor(i,j)
                     !
                 lvf_stateCIOoutdoor(i,j)=fstates(standing,a1,a2,a3,a4,a5,s1,s2,s3,s4)
                !==================

             !===================================
                standing=0;a1=0;a2=0;a3=0;a4=0;a5=0;s1=0;s2=0;s3=0;s4=0

                  a1=lvf_fluxWWtoTWWTP_MgMonth(i,j)                  
                  s1=  lvf_fluxTWWTPtoEffluent(i,j)
                  s2=  lvf_fluxTWWTPtoWWdischarge_MgMonth(i,j)
                  standing=lvf_stateTWWTP(i,j)
                  !
              lvf_stateTWWTP(i,j)=fstates(standing,a1,a2,a3,a4,a5,s1,s2,s3,s4)
             !==================

            !===================================
                standing=0;a1=0;a2=0;a3=0;a4=0;a5=0;s1=0;s2=0;s3=0;s4=0

                  a1=lvf_fluxWWtoRWWTP_MgMonth(i,j)
                  s1=lvf_fluxRWWTPtoRO_MgMonth(i,j)
                  s2= lvf_fluxRWWTPtoReclaimed_MgMonth(i,j)
                  standing= lvf_stateRWWTP(i,j)
                  !
              lvf_stateRWWTP(i,j) =fstates(standing,a1,a2,a3,a4,a5,s1,s2,s3,s4)
             !==================

             !===================================
                standing=0;a1=0;a2=0;a3=0;a4=0;a5=0;s1=0;s2=0;s3=0;s4=0

                  a1= lvf_fluxRWWTPtoRO_MgMonth(i,j) 
                  s1=0 ; s2=lvf_fluxROToDInject_MgMonth(i,j)  
                  standing=lvf_stateRO(i,j)     
                  !
              lvf_stateRO(i,j)=fstates(standing,a1,a2,a3,a4,a5,s1,s2,s3,s4)
             !==================

             !===================================
                standing=0;a1=0;a2=0;a3=0;a4=0;a5=0;s1=0;s2=0;s3=0;s4=0

                  a1= lvf_fluxRWWTPtoReclaimed_MgMonth(i,j) 
                  s1= lvf_reclaimedToInput_MgMonth(i,j); s2=lvf_reclaimedToDinject_MgMonth(i,j)  
                  s3= lvf_reclaimedToVadose_MgMonth(i,j);s4= lvf_reclaimedToWWSurfDisch_MgMonth(i,j)
                  standing=lvf_stateReclaimed(i,j)     
                  !
              lvf_stateReclaimed(i,j)=fstates(standing,a1,a2,a3,a4,a5,s1,s2,s3,s4)
             !==================

             !===================================
             !==================

             !===================================
             !==================

             !===================================

             !==================

             !===================================
                standing=0;a1=0;a2=0;a3=0;a4=0;a5=0;s1=0;s2=0;s3=0;s4=0

                  a1=lvf_reclaimedToVadose_MgMonth(i,j);a2=lvf_fluxRESoutdoorPerc_MgMonth(i,j)
                  a3=lvf_fluxCIOoutdoorPerc_MgMonth(i,j);a4= 0
                  a5= lvf_fluxRunoffPerc_MgMonth(i,j)+ lvf_fluxAgPerc_MgMonth(i,j)
                  s1= lvf_fluxNaturalRecharge_MgMonth(i,j)
                  !
              lvf_stateVadose(i,j) =fstates(standing,a1,a2,a3,a4,a5,s1,s2,s3,s4)
             !==================

             !===================================
                standing=0;a1=0;a2=0;a3=0;a4=0;a5=0;s1=0;s2=0;s3=0;s4=0

                  a1=lvf_fluxNaturalRecharge_MgMonth(i,j)
                  s1=lvf_fluxSaltInMuniGwaterPumped_MgMonth(i,j)
                  !
              lvf_stateAquifer(i,j) =fstates(standing,a1,a2,a3,a4,a5,s1,s2,s3,s4)
             !==================

             !===================================
                standing=0;a1=0;a2=0;a3=0;a4=0;a5=0;s1=0;s2=0;s3=0;s4=0

                  a1=0;a2=lvf_fluxGroundwaterToAg_MgMonth(i,j)
                  a3=0
                  s1= lvf_fluxAgPerc_MgMonth(i,j)
                  !
              lvf_stateAgIrrig(i,j) =fstates(standing,a1,a2,a3,a4,a5,s1,s2,s3,s4)
             !==================
            !
            return
          end subroutine states
          ! --------------------

        ! -----------------------
        subroutine startup(T,i,j)
          integer :: i,j
          type(runTime)T
          ! =====================
            ! 
            if(T%year == T%startyear .and. i == 1 .and. j == 1)gvl_startup=.true.
            !
        end subroutine startup
        ! --------------------

        ! -------------------
        subroutine teardown()
              if(gvl_startup)then
              if(gvl_WriteToDisk)&
               write(7,*)"Once through TDS for City Model:"
            endif
            gvl_startup=.false.
        end subroutine teardown
        ! ----------------------
  !
End Module lms_TDScityModel
!
    ! Called from Water_CityModel
    ! ---------------------------------------
    subroutine sCityModelSalinity(T,i,j,lvSB)
      use lms_TDScityModel
       use gm_ModelControl
        integer :: i,j

         type(SalinityWB)lvSB
         type(runTime)T
        ! =====================
          ! 
          call startup(T,i,j)
           call TDS(T,i,j,lvSB)
          call teardown()
          !
        return
    end subroutine sCityModelSalinity
    ! -------------------------------
!    
! =================================================================================================
! E.O.F.