!
! File is WaterShed.f90 (formally SurfaceWater.f90)
!
!   This file combines outputs from the Salt-Verde-tonto River System with
! outputs from the Colorado River System.
!
! OUTPUTS:
!
! created on 09.30.09
!
! david arthur sampson
! last write was: 02.10.12
! -------------------------------------------------------------------------------------------------
!
Module lms_WaterShed
 use gm_ModelControl
  use gm_GlobalData
   use gm_TypeControl
   
    implicit none
   ! -------------

    ! ---------------------------
    !    Local Outputs
       
    ! ----------
    ! ------------------------------------------------
    !
    include 'C:\WaterSim\WaterSimTesting\WaterSimTesting\bin\Debug\App_Data\WaterSim_4_0\App_Data\Include\WaterSimDCDC.txt'
    !
 contains
   subroutine localOutputs_Ws(T,Aout,Bout,Sout)
    ! Constant variables
!     real :: cv_riverloses=28000   ! RIver loses between release and granite reef (2008 assured water suply study, SRP- on file)
     real :: lvf_addSRP
     type(RiverA)Aout
     type(RiverB)Bout
     type(Surfacewater)Sout
     type(runTime)T
    ! ==============
        !
        ! ----------------------------------------
        ! Prior to distribution
        ! ---------------------
        Sout%sCAPmaricopa_maf=Bout%bCAPmaricopa                 ! Maricopa CAP deliverly (maf a-1)
        Sout%sCAP_maf=Bout%bCAP_maf  
        Sout%sSVTflow_maf=Aout%aFlow                            ! annual flow for SVT (maf a-1)
        Sout%sSVTPreRelease_maf=Aout%aPreReleaseExcess          ! overflow on the SVT - granite reef to 32nd street (maf a-1)       
        !
        ! Lagged by one year (unfortunately)
        ! Is this T%year or T%year-1 ? (Should it be T%year - 1?)
        ! 03.05.12 DAS
         lvf_addSRP=0
!        lvf_addSRP=Aout%gvd_SRP_release_maf_yr(T%year)
         Sout%sMaricopaSWS_maf=0
        Sout%sMaricopaSWS_maf=Bout%bCAPmaricopa+lvf_addSRP
        !
    return
  end subroutine localOutputs_Ws
  ! ----------------------------

  ! ---------------------------------
  subroutine globalOutputs_Ws(T,Bout)
     type(RiverB)Bout
     type(runTime)T
     !
     go_deliveriesCO=NINT(Bout%bCAPmaricopa*(1./gpd_acftTomaf))
     !
1   format(I4,1x,F10.7)
2   format(I4,1x,2(I4,1x),1x,F4.1,1x,2(F10.1,2x),1x,3(F6.3,2x))
     !
  end subroutine globalOutputs_Ws
  ! -----------------------------

  ! ------------------
  subroutine initGW(T)
    integer i
    real  :: vInitGW2006(gvi_maxProV)
    !
    type(runTime)T
     call InitGroundwater2006(vInitGW2006)
    ! 02.02.12 DAS
      do i = 1,gvi_Providers,1
        if(0 < gvi_ProviderGroundWater_a(i))then
         vState_WB_Aquifer(T%startyear,i)= gvi_ProviderGroundWater_a(i)
        else
         vState_WB_Aquifer(T%startyear,i)=vInitGW2006(i)
        endif     !
      end do 
    !
  end subroutine initGW
  ! -------------------
 !
End Module lms_WaterShed
!
  ! ----------------------------------
  subroutine sRivers(T,Aout,Bout,Sout)
   use gm_ModelControl
    use  lms_WaterShed

     type(RiverA)Aout
     type(RiverB)Bout
     type(Surfacewater)Sout
     type(runTime)T
     ! ===============
      !
      if(T%startyear == T%year)then
       call initGW(T)
      endif
      call localOutputs_Ws(T,Aout,Bout,Sout)
      call globalOutputs_Ws(T,Bout)
      ! --------------------------
      !
    return
  end subroutine sRivers
 ! ---------------------

  ! --------------------------------
  subroutine sDesignate(T,Aout,Sout)
   use gm_ModelControl
    use gm_TypeControl

       integer :: i
       real, parameter :: cvf_NCSVolume=0.272500
       real :: cvf_NCS(10)
       data cvf_NCS(1),cvf_NCS(2),cvf_NCS(3),cvf_NCS(4),cvf_NCS(5),cvf_NCS(6) &
         ,cvf_NCS(7),cvf_NCS(8),cvf_NCS(9),cvf_NCS(10) /0,0.1,0,0.1,0.15,0,0.5,0.1,0.05,0/

     type(RiverA)Aout
     type(Surfacewater)Sout
     type(runTime)T
     ! ===============
      ! Moved here because release now falls at the end of the cycle
        do i = 1,10,1
            Aout%gvf_SRP_NCSmaxAllocations(i)=cvf_NCS(i)*cvf_NCSVolume
        end do
        !
        Sout%gvf_pumpBandC_35_AF= Aout%gvf_classBCavailableTopump
        Sout%sNCSmaxAllocations_maf= Aout%gvf_SRP_NCSmaxAllocations
        !
        do i = 1,gvi_Providers,1
          Sout%lvf_unusedClass_A_AF(i)= Aout%gvf_Unused_Class_A_AF(i)
        end do
        !
    return
  end subroutine sDesignate
  ! -----------------------

       ! -----------------------------------------
       subroutine InitGroundwater2006(vInitGW2006)

            real(4) :: vInitGW2006(35)
            ! MODFLOW is connected.  These are the 2006 head estimates
            ! for available water
            ! 02.21.12
            ! ========================================================
             vInitGW2006(1)= 485969
              vInitGW2006(2)= 30201
              vInitGW2006(3)= 1555862
              vInitGW2006(4)= 535278
              vInitGW2006(5)= 121635
              vInitGW2006(6)= 523869
              vInitGW2006(7)= 39259
              vInitGW2006(8)= 100060
              vInitGW2006(9)= 0
             vInitGW2006(10)= 11434
             vInitGW2006(11)= 4421799
             vInitGW2006(12)= 0
             vInitGW2006(13)= 246813
             vInitGW2006(14)= 38707
             vInitGW2006(15)= 87741
             vInitGW2006(16)= 857694
             vInitGW2006(17)= 3059241
             vInitGW2006(18)= 2559037
             vInitGW2006(19)= 411397
             vInitGW2006(20)= 1297378
             vInitGW2006(21)= 7289697
             vInitGW2006(22)= 41109920
             vInitGW2006(23)= 6054963
             vInitGW2006(24)= 42962552
             vInitGW2006(25)= 6388062
             vInitGW2006(26)= 1773472
             vInitGW2006(27)= 7567173
             vInitGW2006(28)= 824477
             vInitGW2006(29)= 44170
             vInitGW2006(30)= 2294354
             vInitGW2006(31)= 97029
             vInitGW2006(32)= 2547923
             vInitGW2006(33)= 70547
             vInitGW2006(34)= 406062
             vInitGW2006(35)= 277712

!            vInitGW2006(1)= 472717
!            vInitGW2006(2)= 27181
!            vInitGW2006(3)= 1402444
!            vInitGW2006(4)= 481010
!            vInitGW2006(5)= 119409
!            vInitGW2006(6)= 519198
!            vInitGW2006(7)= 35333
!            vInitGW2006(8)= 110742
!            vInitGW2006(9)= 0
!            vInitGW2006(10)=10291
!            vInitGW2006(11)=4212952
!            vInitGW2006(12)=0
!            vInitGW2006(13)=222185
!            vInitGW2006(14)=45556
!            vInitGW2006(15)=78967
!            vInitGW2006(16)=790266
!            vInitGW2006(17)=2854934
!            vInitGW2006(18)=2433664
!            vInitGW2006(19)=451139
!            vInitGW2006(20)=1274914
!            vInitGW2006(21)=7629169
!            vInitGW2006(22)=41109921
!            vInitGW2006(23)=6054963
!            vInitGW2006(24)=1637063
!            vInitGW2006(25)=7577589
!            vInitGW2006(26)=743250
!            vInitGW2006(27)=72061
!            vInitGW2006(28)=0
!            vInitGW2006(29)=87326
!            vInitGW2006(30)=2294354
!            vInitGW2006(31)=63493
!            vInitGW2006(32)=449919
!            vInitGW2006(33)=275345
!            vInitGW2006(34)=53041
!            vInitGW2006(35)=75601
        end subroutine InitGroundwater2006
        ! --------------------------------
! 
! =================================================================================================
! E.O.F.